#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_fast_mode import enable_fast_mode as enable_fast_mode_cls
from .enable_memory_saving_mode import enable_memory_saving_mode as enable_memory_saving_mode_cls
from .disable_warped_face_gradient_correction import disable_warped_face_gradient_correction as disable_warped_face_gradient_correction_cls
class enable(Group):
    """
    'enable' child.
    """

    fluent_name = "enable?"

    child_names = \
        ['enable_fast_mode', 'enable_memory_saving_mode']

    enable_fast_mode: enable_fast_mode_cls = enable_fast_mode_cls
    """
    enable_fast_mode child of enable.
    """
    enable_memory_saving_mode: enable_memory_saving_mode_cls = enable_memory_saving_mode_cls
    """
    enable_memory_saving_mode child of enable.
    """
    command_names = \
        ['disable_warped_face_gradient_correction']

    disable_warped_face_gradient_correction: disable_warped_face_gradient_correction_cls = disable_warped_face_gradient_correction_cls
    """
    disable_warped_face_gradient_correction command of enable.
    """



"""Module containing class encapsulating Fluent connection and the Base Session."""
import importlib
import json
import logging
from typing import Any, Optional
import warnings

from ansys.fluent.core.fluent_connection import FluentConnection
from ansys.fluent.core.journaling import Journal
from ansys.fluent.core.services import service_creator
from ansys.fluent.core.services.batch_ops import BatchOpsService
from ansys.fluent.core.services.events import EventsService
from ansys.fluent.core.services.field_data import FieldDataService
from ansys.fluent.core.session_shared import (  # noqa: F401
    _CODEGEN_MSG_DATAMODEL,
    _CODEGEN_MSG_TUI,
)
from ansys.fluent.core.streaming_services.datamodel_event_streaming import (
    DatamodelEvents,
)
from ansys.fluent.core.streaming_services.events_streaming import EventsManager
from ansys.fluent.core.streaming_services.field_data_streaming import FieldDataStreaming
from ansys.fluent.core.streaming_services.monitor_streaming import MonitorsManager
from ansys.fluent.core.streaming_services.transcript_streaming import Transcript
from ansys.fluent.core.utils.file_transfer_service import PimFileTransferService
import ansys.platform.instancemanagement as pypim

from .rpvars import RPVars

try:
    from ansys.fluent.core.solver.settings import root
except Exception:
    root = Any

datamodel_logger = logging.getLogger("pyfluent.datamodel")
logger = logging.getLogger("pyfluent.general")


def _parse_server_info_file(file_name: str):
    with open(file_name, encoding="utf-8") as f:
        lines = f.readlines()
    ip_and_port = lines[0].strip().split(":")
    ip = ip_and_port[0]
    port = int(ip_and_port[1])
    password = lines[1].strip()
    return ip, port, password


def _get_datamodel_attributes(session, attribute: str):
    try:
        preferences_module = importlib.import_module(
            f"ansys.fluent.core.datamodel_{session.version}." + attribute
        )
        return preferences_module.Root(session._se_service, attribute, [])
    except ImportError:
        datamodel_logger.warning(_CODEGEN_MSG_DATAMODEL)


def _get_preferences(session):
    return _get_datamodel_attributes(session, "preferences")


class _IsDataValid:
    def __init__(self, scheme_eval):
        self._scheme_eval = scheme_eval

    def __bool__(self):
        return self()

    def __call__(self):
        return self._scheme_eval.scheme_eval("(data-valid?)")


class BaseSession:
    """Instantiates a Fluent connection.

    Attributes
    ----------
    scheme_eval: SchemeEval
        Instance of SchemeEval on which Fluent's scheme code can be
        executed.

    Methods
    -------
    create_from_server_info_file(
        server_info_file_name, cleanup_on_exit, start_transcript
        )
        Create a Session instance from server-info file

    exit()
        Close the Fluent connection and exit Fluent.
    """

    _pim_methods = ["upload", "download"]

    def __init__(
        self,
        fluent_connection: FluentConnection,
        remote_file_handler: Optional[Any] = None,
    ):
        """BaseSession.

        Args:
            fluent_connection (:ref:`ref_fluent_connection`): Encapsulates a Fluent connection.
            remote_file_handler: Supports file upload and download.
        """
        BaseSession.build_from_fluent_connection(
            self, fluent_connection, remote_file_handler
        )

    def build_from_fluent_connection(
        self,
        fluent_connection: FluentConnection,
        remote_file_handler: Optional[Any] = None,
    ):
        """Build a BaseSession object from fluent_connection object."""
        self.fluent_connection = fluent_connection
        self._remote_file_handler = remote_file_handler
        self.error_state = self.fluent_connection.error_state
        self.scheme_eval = self.fluent_connection.scheme_eval
        self.rp_vars = RPVars(self.scheme_eval.string_eval)
        self._preferences = None
        self.journal = Journal(self.scheme_eval)

        self.transcript = self.fluent_connection.create_grpc_service(Transcript)
        if fluent_connection.start_transcript:
            self.transcript.start()

        self.datamodel_service_tui = service_creator("tui").create(
            fluent_connection._channel,
            fluent_connection._metadata,
            self.error_state,
            self.scheme_eval,
        )

        self.datamodel_service_se = service_creator("datamodel").create(
            fluent_connection._channel,
            fluent_connection._metadata,
            self.error_state,
        )

        self.datamodel_events = DatamodelEvents(self.datamodel_service_se)
        self.datamodel_events.start()

        self._batch_ops_service = self.fluent_connection.create_grpc_service(
            BatchOpsService
        )
        self.events_service = self.fluent_connection.create_grpc_service(EventsService)
        self.events_manager = EventsManager(
            self.events_service, self.error_state, self.fluent_connection._id
        )

        self._monitors_service = service_creator("monitors").create(
            fluent_connection._channel, fluent_connection._metadata, self.error_state
        )
        self.monitors_manager = MonitorsManager(
            self.fluent_connection._id, self._monitors_service
        )

        self.events_manager.register_callback(
            "InitializedEvent", self.monitors_manager.refresh
        )
        self.events_manager.register_callback(
            "DataReadEvent", self.monitors_manager.refresh
        )

        self.events_manager.start()

        self._field_data_service = self.fluent_connection.create_grpc_service(
            FieldDataService, self.error_state
        )
        self.field_info = service_creator("field_info").create(
            self._field_data_service, _IsDataValid(self.scheme_eval)
        )
        self.field_data = service_creator("field_data").create(
            self._field_data_service,
            self.field_info,
            _IsDataValid(self.scheme_eval),
            self.scheme_eval,
        )
        self.field_data_streaming = FieldDataStreaming(
            self.fluent_connection._id, self._field_data_service
        )

        self.settings_service = service_creator("settings").create(
            fluent_connection._channel,
            fluent_connection._metadata,
            self.scheme_eval,
            self.error_state,
        )

        self.health_check_service = fluent_connection.health_check_service
        self.connection_properties = fluent_connection.connection_properties

        self.fluent_connection.register_finalizer_cb(
            self.datamodel_service_se.unsubscribe_all_events
        )
        for obj in (
            self.datamodel_events,
            self.transcript,
            self.events_manager,
            self.monitors_manager,
        ):
            self.fluent_connection.register_finalizer_cb(obj.stop)

    @property
    def id(self) -> str:
        """Return the session ID."""
        return self.fluent_connection._id

    def start_journal(self, file_name: str):
        """Executes tui command to start journal."""
        warnings.warn("Use -> journal.start()", DeprecationWarning)
        self.journal.start(file_name)

    def stop_journal(self):
        """Executes tui command to stop journal."""
        warnings.warn("Use -> journal.stop()", DeprecationWarning)
        self.journal.stop()

    @classmethod
    def create_from_server_info_file(
        cls,
        server_info_file_name: str,
        remote_file_handler: Optional[Any] = None,
        **connection_kwargs,
    ):
        """Create a Session instance from server-info file.

        Parameters
        ----------
        server_info_file_name : str
            Path to server-info file written out by Fluent server
        remote_file_handler : Optional
            Support file upload and download.
        **connection_kwargs : dict, optional
            Additional keyword arguments may be specified, and they will be passed to the `FluentConnection`
            being initialized. For example, ``cleanup_on_exit = True``, or ``start_transcript = True``.
            See :func:`FluentConnection initialization <ansys.fluent.core.fluent_connection.FluentConnection.__init__>`
            for more details and possible arguments.

        Returns
        -------
        Session
            Session instance
        """
        ip, port, password = _parse_server_info_file(server_info_file_name)
        session = cls(
            fluent_connection=FluentConnection(
                ip=ip, port=port, password=password, **connection_kwargs
            ),
            remote_file_handler=remote_file_handler,
        )
        return session

    def execute_tui(self, command: str) -> None:
        """Executes a tui command."""
        self.scheme_eval.scheme_eval(f"(ti-menu-load-string {json.dumps(command)})")

    def get_fluent_version(self):
        """Gets and returns the fluent version."""
        return self.scheme_eval.version

    def exit(self, **kwargs) -> None:
        """Exit session."""
        logger.debug("session.exit() called")
        self.fluent_connection.exit(**kwargs)

    def force_exit(self) -> None:
        """Terminate session."""
        self.fluent_connection.force_exit()

    def force_exit_container(self) -> None:
        """Terminate Docker container session."""
        self.fluent_connection.force_exit_container()

    def upload(self, file_name: str, remote_file_name: Optional[str] = None):
        """Upload a file to the server supported by `PyPIM<https://pypim.docs.pyansys.com/version/stable/>`.

        Parameters
        ----------
        file_name : str
            file name
        remote_file_name : str, optional
            remote file name, by default None
        """
        return PimFileTransferService(self.fluent_connection._remote_instance).upload(
            file_name, remote_file_name
        )

    def download(self, file_name: str, local_file_name: Optional[str] = "."):
        """Download a file from the server supported by `PyPIM<https://pypim.docs.pyansys.com/version/stable/>`.

        Parameters
        ----------
        file_name : str
            file name
        local_file_name : str, optional
            local file path, by default current directory
        """
        return PimFileTransferService(self.fluent_connection._remote_instance).download(
            file_name, local_file_name
        )

    def __dir__(self):
        returned_list = sorted(set(list(self.__dict__.keys()) + dir(type(self))))
        if not pypim.is_configured():
            for method in BaseSession._pim_methods:
                if method in returned_list:
                    returned_list.remove(method)
        return returned_list

    def __enter__(self):
        return self

    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any):
        """Close the Fluent connection and exit Fluent."""
        logger.debug("session.__exit__() called")
        self.exit()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_24 import phase as phase_cls
from .name_1 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .d import d as d_cls
from .q_dot import q_dot as q_dot_cls
from .material import material as material_cls
from .thermal_bc import thermal_bc as thermal_bc_cls
from .t import t as t_cls
from .q import q as q_cls
from .h import h as h_cls
from .tinf_1 import tinf as tinf_cls
from .planar_conduction import planar_conduction as planar_conduction_cls
from .shell_conduction import shell_conduction as shell_conduction_cls
from .thin_wall import thin_wall as thin_wall_cls
from .motion_bc import motion_bc as motion_bc_cls
from .shear_bc import shear_bc as shear_bc_cls
from .rough_bc import rough_bc as rough_bc_cls
from .moving import moving as moving_cls
from .relative import relative as relative_cls
from .rotating import rotating as rotating_cls
from .vmag import vmag as vmag_cls
from .wall_translation import wall_translation as wall_translation_cls
from .components_1 import components as components_cls
from .velocity_1 import velocity as velocity_cls
from .in_emiss import in_emiss as in_emiss_cls
from .ex_emiss import ex_emiss as ex_emiss_cls
from .trad import trad as trad_cls
from .int_rad import int_rad as int_rad_cls
from .trad_internal import trad_internal as trad_internal_cls
from .area_enhancement_factor import area_enhancement_factor as area_enhancement_factor_cls
from .rough_option import rough_option as rough_option_cls
from .rough_nasa import rough_nasa as rough_nasa_cls
from .rough_shin_et_al import rough_shin_et_al as rough_shin_et_al_cls
from .rough_data import rough_data as rough_data_cls
from .roughness_height import roughness_height as roughness_height_cls
from .roughness_const import roughness_const as roughness_const_cls
from .roughness_height_cp import roughness_height_cp as roughness_height_cp_cls
from .roughness_const_cp import roughness_const_cp as roughness_const_cp_cls
from .roughness_const_nasa import roughness_const_nasa as roughness_const_nasa_cls
from .roughness_const_shin import roughness_const_shin as roughness_const_shin_cls
from .roughness_const_data import roughness_const_data as roughness_const_data_cls
from .variable_roughness import variable_roughness as variable_roughness_cls
from .free_stream_velocity import free_stream_velocity as free_stream_velocity_cls
from .free_stream_temp import free_stream_temp as free_stream_temp_cls
from .characteristic_length import characteristic_length as characteristic_length_cls
from .free_stream_temp_cp import free_stream_temp_cp as free_stream_temp_cp_cls
from .characteristic_length_cp import characteristic_length_cp as characteristic_length_cp_cls
from .liquid_content import liquid_content as liquid_content_cls
from .liquid_content_cp import liquid_content_cp as liquid_content_cp_cls
from .droplet_diameter import droplet_diameter as droplet_diameter_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_norm_coeff import dpm_bc_norm_coeff as dpm_bc_norm_coeff_cls
from .dpm_bc_tang_coeff import dpm_bc_tang_coeff as dpm_bc_tang_coeff_cls
from .dpm_bc_frictn_coeff import dpm_bc_frictn_coeff as dpm_bc_frictn_coeff_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .dpm_film_splash_nsamp import dpm_film_splash_nsamp as dpm_film_splash_nsamp_cls
from .dpm_crit_temp_option import dpm_crit_temp_option as dpm_crit_temp_option_cls
from .dpm_critical_temp_factor import dpm_critical_temp_factor as dpm_critical_temp_factor_cls
from .dpm_calibratable_temp import dpm_calibratable_temp as dpm_calibratable_temp_cls
from .dpm_impingement_splashing_model import dpm_impingement_splashing_model as dpm_impingement_splashing_model_cls
from .dpm_upper_deposition_limit_offset import dpm_upper_deposition_limit_offset as dpm_upper_deposition_limit_offset_cls
from .dpm_deposition_delta_t import dpm_deposition_delta_t as dpm_deposition_delta_t_cls
from .dpm_laplace_number_constant import dpm_laplace_number_constant as dpm_laplace_number_constant_cls
from .dpm_partial_evaporation_ratio import dpm_partial_evaporation_ratio as dpm_partial_evaporation_ratio_cls
from .ra_roughness import ra_roughness as ra_roughness_cls
from .rz_roughness import rz_roughness as rz_roughness_cls
from .rq_roughness import rq_roughness as rq_roughness_cls
from .rsm_roughness import rsm_roughness as rsm_roughness_cls
from .dpm_bc_erosion_generic import dpm_bc_erosion_generic as dpm_bc_erosion_generic_cls
from .dpm_bc_erosion import dpm_bc_erosion as dpm_bc_erosion_cls
from .dpm_bc_erosion_c import dpm_bc_erosion_c as dpm_bc_erosion_c_cls
from .dpm_bc_erosion_n import dpm_bc_erosion_n as dpm_bc_erosion_n_cls
from .dpm_bc_erosion_finnie import dpm_bc_erosion_finnie as dpm_bc_erosion_finnie_cls
from .dpm_bc_erosion_finnie_k import dpm_bc_erosion_finnie_k as dpm_bc_erosion_finnie_k_cls
from .dpm_bc_erosion_finnie_vel_exp import dpm_bc_erosion_finnie_vel_exp as dpm_bc_erosion_finnie_vel_exp_cls
from .dpm_bc_erosion_finnie_max_erosion_angle import dpm_bc_erosion_finnie_max_erosion_angle as dpm_bc_erosion_finnie_max_erosion_angle_cls
from .dpm_bc_erosion_mclaury import dpm_bc_erosion_mclaury as dpm_bc_erosion_mclaury_cls
from .dpm_bc_erosion_mclaury_a import dpm_bc_erosion_mclaury_a as dpm_bc_erosion_mclaury_a_cls
from .dpm_bc_erosion_mclaury_vel_exp import dpm_bc_erosion_mclaury_vel_exp as dpm_bc_erosion_mclaury_vel_exp_cls
from .dpm_bc_erosion_mclaury_transition_angle import dpm_bc_erosion_mclaury_transition_angle as dpm_bc_erosion_mclaury_transition_angle_cls
from .dpm_bc_erosion_mclaury_b import dpm_bc_erosion_mclaury_b as dpm_bc_erosion_mclaury_b_cls
from .dpm_bc_erosion_mclaury_c import dpm_bc_erosion_mclaury_c as dpm_bc_erosion_mclaury_c_cls
from .dpm_bc_erosion_mclaury_w import dpm_bc_erosion_mclaury_w as dpm_bc_erosion_mclaury_w_cls
from .dpm_bc_erosion_mclaury_x import dpm_bc_erosion_mclaury_x as dpm_bc_erosion_mclaury_x_cls
from .dpm_bc_erosion_mclaury_y import dpm_bc_erosion_mclaury_y as dpm_bc_erosion_mclaury_y_cls
from .dpm_bc_erosion_oka import dpm_bc_erosion_oka as dpm_bc_erosion_oka_cls
from .dpm_bc_erosion_oka_e90 import dpm_bc_erosion_oka_e90 as dpm_bc_erosion_oka_e90_cls
from .dpm_bc_erosion_oka_hv import dpm_bc_erosion_oka_hv as dpm_bc_erosion_oka_hv_cls
from .dpm_bc_erosion_oka_n1 import dpm_bc_erosion_oka_n1 as dpm_bc_erosion_oka_n1_cls
from .dpm_bc_erosion_oka_n2 import dpm_bc_erosion_oka_n2 as dpm_bc_erosion_oka_n2_cls
from .dpm_bc_erosion_oka_k2 import dpm_bc_erosion_oka_k2 as dpm_bc_erosion_oka_k2_cls
from .dpm_bc_erosion_oka_k3 import dpm_bc_erosion_oka_k3 as dpm_bc_erosion_oka_k3_cls
from .dpm_bc_erosion_oka_dref import dpm_bc_erosion_oka_dref as dpm_bc_erosion_oka_dref_cls
from .dpm_bc_erosion_oka_vref import dpm_bc_erosion_oka_vref as dpm_bc_erosion_oka_vref_cls
from .dpm_bc_erosion_dnv import dpm_bc_erosion_dnv as dpm_bc_erosion_dnv_cls
from .dpm_bc_erosion_dnv_k import dpm_bc_erosion_dnv_k as dpm_bc_erosion_dnv_k_cls
from .dpm_bc_erosion_dnv_n import dpm_bc_erosion_dnv_n as dpm_bc_erosion_dnv_n_cls
from .dpm_bc_erosion_dnv_ductile import dpm_bc_erosion_dnv_ductile as dpm_bc_erosion_dnv_ductile_cls
from .dpm_bc_erosion_shear import dpm_bc_erosion_shear as dpm_bc_erosion_shear_cls
from .dpm_bc_erosion_shear_v import dpm_bc_erosion_shear_v as dpm_bc_erosion_shear_v_cls
from .dpm_bc_erosion_shear_c import dpm_bc_erosion_shear_c as dpm_bc_erosion_shear_c_cls
from .dpm_bc_erosion_shear_packing_limit import dpm_bc_erosion_shear_packing_limit as dpm_bc_erosion_shear_packing_limit_cls
from .dpm_bc_erosion_shielding import dpm_bc_erosion_shielding as dpm_bc_erosion_shielding_cls
from .dpm_wall_heat_exchange import dpm_wall_heat_exchange as dpm_wall_heat_exchange_cls
from .dpm_film_condensation import dpm_film_condensation as dpm_film_condensation_cls
from .dpm_film_bl_model import dpm_film_bl_model as dpm_film_bl_model_cls
from .dpm_particle_stripping import dpm_particle_stripping as dpm_particle_stripping_cls
from .dpm_critical_shear_stress import dpm_critical_shear_stress as dpm_critical_shear_stress_cls
from .dpm_film_separation_model import dpm_film_separation_model as dpm_film_separation_model_cls
from .dpm_critical_we_number import dpm_critical_we_number as dpm_critical_we_number_cls
from .dpm_film_separation_angle import dpm_film_separation_angle as dpm_film_separation_angle_cls
from .dpm_allow_lwf_to_vof import dpm_allow_lwf_to_vof as dpm_allow_lwf_to_vof_cls
from .dpm_allow_vof_to_lwf import dpm_allow_vof_to_lwf as dpm_allow_vof_to_lwf_cls
from .dpm_initialize_lwf import dpm_initialize_lwf as dpm_initialize_lwf_cls
from .dpm_initial_height import dpm_initial_height as dpm_initial_height_cls
from .film_velocity import film_velocity as film_velocity_cls
from .dpm_initial_temperature import dpm_initial_temperature as dpm_initial_temperature_cls
from .dpm_initial_injection import dpm_initial_injection as dpm_initial_injection_cls
from .film_parcel_surface_area_density import film_parcel_surface_area_density as film_parcel_surface_area_density_cls
from .minimum_number_of_parcels_per_face import minimum_number_of_parcels_per_face as minimum_number_of_parcels_per_face_cls
from .band_in_emiss import band_in_emiss as band_in_emiss_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .mc_bsource_p import mc_bsource_p as mc_bsource_p_cls
from .mc_poldfun_p import mc_poldfun_p as mc_poldfun_p_cls
from .polar_func_type import polar_func_type as polar_func_type_cls
from .mc_polar_expr import mc_polar_expr as mc_polar_expr_cls
from .polar_pair_list import polar_pair_list as polar_pair_list_cls
from .pold_pair_list_rad import pold_pair_list_rad as pold_pair_list_rad_cls
from .radiation_direction import radiation_direction as radiation_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .band_diffuse_frac import band_diffuse_frac as band_diffuse_frac_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .critical_zone import critical_zone as critical_zone_cls
from .fpsc import fpsc as fpsc_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .v_transmissivity import v_transmissivity as v_transmissivity_cls
from .ir_transmissivity import ir_transmissivity as ir_transmissivity_cls
from .v_opq_absorbtivity import v_opq_absorbtivity as v_opq_absorbtivity_cls
from .ir_opq_absorbtivity import ir_opq_absorbtivity as ir_opq_absorbtivity_cls
from .v_st_absorbtivity import v_st_absorbtivity as v_st_absorbtivity_cls
from .ir_st_absorbtivity import ir_st_absorbtivity as ir_st_absorbtivity_cls
from .d_st_absorbtivity import d_st_absorbtivity as d_st_absorbtivity_cls
from .d_transmissivity import d_transmissivity as d_transmissivity_cls
from .fsi_interface import fsi_interface as fsi_interface_cls
from .react import react as react_cls
from .partially_catalytic import partially_catalytic as partially_catalytic_cls
from .partially_catalytic_material import partially_catalytic_material as partially_catalytic_material_cls
from .partially_catalytic_recombination_coefficient_o import partially_catalytic_recombination_coefficient_o as partially_catalytic_recombination_coefficient_o_cls
from .partially_catalytic_recombination_coefficient_n import partially_catalytic_recombination_coefficient_n as partially_catalytic_recombination_coefficient_n_cls
from .partially_catalytic_recombination_model import partially_catalytic_recombination_model as partially_catalytic_recombination_model_cls
from .species_spec import species_spec as species_spec_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .elec_potential_jump import elec_potential_jump as elec_potential_jump_cls
from .elec_potential_resistance import elec_potential_resistance as elec_potential_resistance_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .echem_reaction import echem_reaction as echem_reaction_cls
from .elec_potential_mechs import elec_potential_mechs as elec_potential_mechs_cls
from .faradaic_heat import faradaic_heat as faradaic_heat_cls
from .li_ion_type import li_ion_type as li_ion_type_cls
from .li_ion_value import li_ion_value as li_ion_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .per_dispx import per_dispx as per_dispx_cls
from .per_dispy import per_dispy as per_dispy_cls
from .per_dispz import per_dispz as per_dispz_cls
from .per_imagx import per_imagx as per_imagx_cls
from .per_imagy import per_imagy as per_imagy_cls
from .per_imagz import per_imagz as per_imagz_cls
from .freq import freq as freq_cls
from .amp import amp as amp_cls
from .nodal_diam import nodal_diam as nodal_diam_cls
from .pass_number import pass_number as pass_number_cls
from .fwd import fwd as fwd_cls
from .aero import aero as aero_cls
from .cmplx import cmplx as cmplx_cls
from .norm import norm as norm_cls
from .method_4 import method as method_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .gtemp_bc import gtemp_bc as gtemp_bc_cls
from .g_temperature import g_temperature as g_temperature_cls
from .g_qflux import g_qflux as g_qflux_cls
from .wall_restitution_coeff import wall_restitution_coeff as wall_restitution_coeff_cls
from .omega import omega as omega_cls
from .rotation_axis_origin import rotation_axis_origin as rotation_axis_origin_cls
from .rotation_axis_direction import rotation_axis_direction as rotation_axis_direction_cls
from .adhesion_angle import adhesion_angle as adhesion_angle_cls
from .specified_shear import specified_shear as specified_shear_cls
from .shear_stress import shear_stress as shear_stress_cls
from .fslip import fslip as fslip_cls
from .eslip import eslip as eslip_cls
from .surf_tens_grad import surf_tens_grad as surf_tens_grad_cls
from .contact_resistance import contact_resistance as contact_resistance_cls
from .reaction_mechs_1 import reaction_mechs as reaction_mechs_cls
from .surf_washcoat_factor import surf_washcoat_factor as surf_washcoat_factor_cls
from .initial_deposition_height import initial_deposition_height as initial_deposition_height_cls
from .solid_species_density import solid_species_density as solid_species_density_cls
from .ablation_select_model import ablation_select_model as ablation_select_model_cls
from .ablation_vielle_a import ablation_vielle_a as ablation_vielle_a_cls
from .ablation_vielle_n import ablation_vielle_n as ablation_vielle_n_cls
from .ablation_flux import ablation_flux as ablation_flux_cls
from .ablation_surfacerxn_density import ablation_surfacerxn_density as ablation_surfacerxn_density_cls
from .ablation_species_mf import ablation_species_mf as ablation_species_mf_cls
from .specular_coeff import specular_coeff as specular_coeff_cls
from .mom_accom_coef import mom_accom_coef as mom_accom_coef_cls
from .therm_accom_coef import therm_accom_coef as therm_accom_coef_cls
from .eve_accom_coef import eve_accom_coef as eve_accom_coef_cls
from .film_wall import film_wall as film_wall_cls
from .film_wall_bc import film_wall_bc as film_wall_bc_cls
from .film_height import film_height as film_height_cls
from .flux_momentum import flux_momentum as flux_momentum_cls
from .film_relative_vel import film_relative_vel as film_relative_vel_cls
from .film_bc_imp_press import film_bc_imp_press as film_bc_imp_press_cls
from .film_temperature import film_temperature as film_temperature_cls
from .film_scalar import film_scalar as film_scalar_cls
from .film_source import film_source as film_source_cls
from .film_h_src import film_h_src as film_h_src_cls
from .momentum_source import momentum_source as momentum_source_cls
from .film_t_src import film_t_src as film_t_src_cls
from .film_s_src import film_s_src as film_s_src_cls
from .film_phase_change import film_phase_change as film_phase_change_cls
from .film_phase_change_model import film_phase_change_model as film_phase_change_model_cls
from .film_cond_const import film_cond_const as film_cond_const_cls
from .film_vapo_const import film_vapo_const as film_vapo_const_cls
from .film_cond_rate import film_cond_rate as film_cond_rate_cls
from .film_vapo_rate import film_vapo_rate as film_vapo_rate_cls
from .film_momentum_coupling import film_momentum_coupling as film_momentum_coupling_cls
from .film_splash_wall import film_splash_wall as film_splash_wall_cls
from .film_boundary_separation import film_boundary_separation as film_boundary_separation_cls
from .film_impinge_model import film_impinge_model as film_impinge_model_cls
from .film_splash_nparc import film_splash_nparc as film_splash_nparc_cls
from .film_crit_temp_factor import film_crit_temp_factor as film_crit_temp_factor_cls
from .film_roughness_ra import film_roughness_ra as film_roughness_ra_cls
from .film_roughness_rz import film_roughness_rz as film_roughness_rz_cls
from .film_upper_deposition_limit_offset import film_upper_deposition_limit_offset as film_upper_deposition_limit_offset_cls
from .film_deposition_delta_t import film_deposition_delta_t as film_deposition_delta_t_cls
from .film_laplace_number_constant import film_laplace_number_constant as film_laplace_number_constant_cls
from .film_partial_evap_ratio import film_partial_evap_ratio as film_partial_evap_ratio_cls
from .film_contact_angle import film_contact_angle as film_contact_angle_cls
from .film_contact_angle_mean import film_contact_angle_mean as film_contact_angle_mean_cls
from .film_contact_angle_rstd import film_contact_angle_rstd as film_contact_angle_rstd_cls
from .film_contact_angle_beta import film_contact_angle_beta as film_contact_angle_beta_cls
from .film_vof_coupling_high import film_vof_coupling_high as film_vof_coupling_high_cls
from .film_vof_trans_high import film_vof_trans_high as film_vof_trans_high_cls
from .film_vof_trans_high_relax import film_vof_trans_high_relax as film_vof_trans_high_relax_cls
from .film_vof_coupling_low import film_vof_coupling_low as film_vof_coupling_low_cls
from .film_vof_trans_low import film_vof_trans_low as film_vof_trans_low_cls
from .film_vof_trans_low_relax import film_vof_trans_low_relax as film_vof_trans_low_relax_cls
from .caf import caf as caf_cls
from .thermal_stabilization import thermal_stabilization as thermal_stabilization_cls
from .scale_factor import scale_factor as scale_factor_cls
from .stab_method import stab_method as stab_method_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_ice_icing_mode import fensapice_ice_icing_mode as fensapice_ice_icing_mode_cls
from .fensapice_ice_hflux import fensapice_ice_hflux as fensapice_ice_hflux_cls
from .fensapice_ice_hflux_1 import fensapice_ice_hflux_1 as fensapice_ice_hflux_1_cls
from .fensapice_drop_vwet import fensapice_drop_vwet as fensapice_drop_vwet_cls
from .fensapice_dpm_wall_condition import fensapice_dpm_wall_condition as fensapice_dpm_wall_condition_cls
from .fensapice_dpm_bc_norm_coeff import fensapice_dpm_bc_norm_coeff as fensapice_dpm_bc_norm_coeff_cls
from .fensapice_dpm_bc_tang_coeff import fensapice_dpm_bc_tang_coeff as fensapice_dpm_bc_tang_coeff_cls
class wall_child(Group):
    """
    'child_object_type' of wall.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread', 'd',
         'q_dot', 'material', 'thermal_bc', 't', 'q', 'h', 'tinf',
         'planar_conduction', 'shell_conduction', 'thin_wall', 'motion_bc',
         'shear_bc', 'rough_bc', 'moving', 'relative', 'rotating', 'vmag',
         'wall_translation', 'components', 'velocity', 'in_emiss', 'ex_emiss',
         'trad', 'int_rad', 'trad_internal', 'area_enhancement_factor',
         'rough_option', 'rough_nasa', 'rough_shin_et_al', 'rough_data',
         'roughness_height', 'roughness_const', 'roughness_height_cp',
         'roughness_const_cp', 'roughness_const_nasa', 'roughness_const_shin',
         'roughness_const_data', 'variable_roughness', 'free_stream_velocity',
         'free_stream_temp', 'characteristic_length', 'free_stream_temp_cp',
         'characteristic_length_cp', 'liquid_content', 'liquid_content_cp',
         'droplet_diameter', 'dpm_bc_type', 'dpm_bc_collision_partner',
         'reinj_inj', 'dpm_bc_norm_coeff', 'dpm_bc_tang_coeff',
         'dpm_bc_frictn_coeff', 'dpm_bc_udf', 'dpm_film_splash_nsamp',
         'dpm_crit_temp_option', 'dpm_critical_temp_factor',
         'dpm_calibratable_temp', 'dpm_impingement_splashing_model',
         'dpm_upper_deposition_limit_offset', 'dpm_deposition_delta_t',
         'dpm_laplace_number_constant', 'dpm_partial_evaporation_ratio',
         'ra_roughness', 'rz_roughness', 'rq_roughness', 'rsm_roughness',
         'dpm_bc_erosion_generic', 'dpm_bc_erosion', 'dpm_bc_erosion_c',
         'dpm_bc_erosion_n', 'dpm_bc_erosion_finnie',
         'dpm_bc_erosion_finnie_k', 'dpm_bc_erosion_finnie_vel_exp',
         'dpm_bc_erosion_finnie_max_erosion_angle', 'dpm_bc_erosion_mclaury',
         'dpm_bc_erosion_mclaury_a', 'dpm_bc_erosion_mclaury_vel_exp',
         'dpm_bc_erosion_mclaury_transition_angle',
         'dpm_bc_erosion_mclaury_b', 'dpm_bc_erosion_mclaury_c',
         'dpm_bc_erosion_mclaury_w', 'dpm_bc_erosion_mclaury_x',
         'dpm_bc_erosion_mclaury_y', 'dpm_bc_erosion_oka',
         'dpm_bc_erosion_oka_e90', 'dpm_bc_erosion_oka_hv',
         'dpm_bc_erosion_oka_n1', 'dpm_bc_erosion_oka_n2',
         'dpm_bc_erosion_oka_k2', 'dpm_bc_erosion_oka_k3',
         'dpm_bc_erosion_oka_dref', 'dpm_bc_erosion_oka_vref',
         'dpm_bc_erosion_dnv', 'dpm_bc_erosion_dnv_k', 'dpm_bc_erosion_dnv_n',
         'dpm_bc_erosion_dnv_ductile', 'dpm_bc_erosion_shear',
         'dpm_bc_erosion_shear_v', 'dpm_bc_erosion_shear_c',
         'dpm_bc_erosion_shear_packing_limit', 'dpm_bc_erosion_shielding',
         'dpm_wall_heat_exchange', 'dpm_film_condensation',
         'dpm_film_bl_model', 'dpm_particle_stripping',
         'dpm_critical_shear_stress', 'dpm_film_separation_model',
         'dpm_critical_we_number', 'dpm_film_separation_angle',
         'dpm_allow_lwf_to_vof', 'dpm_allow_vof_to_lwf', 'dpm_initialize_lwf',
         'dpm_initial_height', 'film_velocity', 'dpm_initial_temperature',
         'dpm_initial_injection', 'film_parcel_surface_area_density',
         'minimum_number_of_parcels_per_face', 'band_in_emiss',
         'radiation_bc', 'mc_bsource_p', 'mc_poldfun_p', 'polar_func_type',
         'mc_polar_expr', 'polar_pair_list', 'pold_pair_list_rad',
         'radiation_direction', 'coll_dtheta', 'coll_dphi', 'band_q_irrad',
         'band_q_irrad_diffuse', 'band_diffuse_frac', 'radiating_s2s_surface',
         'critical_zone', 'fpsc', 'parallel_collimated_beam', 'solar_fluxes',
         'solar_direction', 'solar_irradiation', 'v_transmissivity',
         'ir_transmissivity', 'v_opq_absorbtivity', 'ir_opq_absorbtivity',
         'v_st_absorbtivity', 'ir_st_absorbtivity', 'd_st_absorbtivity',
         'd_transmissivity', 'fsi_interface', 'react', 'partially_catalytic',
         'partially_catalytic_material',
         'partially_catalytic_recombination_coefficient_o',
         'partially_catalytic_recombination_coefficient_n',
         'partially_catalytic_recombination_model', 'species_spec', 'mf',
         'elec_potential_type', 'potential_value', 'elec_potential_jump',
         'elec_potential_resistance', 'dual_potential_type',
         'dual_potential_value', 'echem_reaction', 'elec_potential_mechs',
         'faradaic_heat', 'li_ion_type', 'li_ion_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'per_dispx', 'per_dispy', 'per_dispz',
         'per_imagx', 'per_imagy', 'per_imagz', 'freq', 'amp', 'nodal_diam',
         'pass_number', 'fwd', 'aero', 'cmplx', 'norm', 'method', 'uds_bc',
         'uds', 'gtemp_bc', 'g_temperature', 'g_qflux',
         'wall_restitution_coeff', 'omega', 'rotation_axis_origin',
         'rotation_axis_direction', 'adhesion_angle', 'specified_shear',
         'shear_stress', 'fslip', 'eslip', 'surf_tens_grad',
         'contact_resistance', 'reaction_mechs', 'surf_washcoat_factor',
         'initial_deposition_height', 'solid_species_density',
         'ablation_select_model', 'ablation_vielle_a', 'ablation_vielle_n',
         'ablation_flux', 'ablation_surfacerxn_density',
         'ablation_species_mf', 'specular_coeff', 'mom_accom_coef',
         'therm_accom_coef', 'eve_accom_coef', 'film_wall', 'film_wall_bc',
         'film_height', 'flux_momentum', 'film_relative_vel',
         'film_bc_imp_press', 'film_temperature', 'film_scalar',
         'film_source', 'film_h_src', 'momentum_source', 'film_t_src',
         'film_s_src', 'film_phase_change', 'film_phase_change_model',
         'film_cond_const', 'film_vapo_const', 'film_cond_rate',
         'film_vapo_rate', 'film_momentum_coupling', 'film_splash_wall',
         'film_boundary_separation', 'film_impinge_model',
         'film_splash_nparc', 'film_crit_temp_factor', 'film_roughness_ra',
         'film_roughness_rz', 'film_upper_deposition_limit_offset',
         'film_deposition_delta_t', 'film_laplace_number_constant',
         'film_partial_evap_ratio', 'film_contact_angle',
         'film_contact_angle_mean', 'film_contact_angle_rstd',
         'film_contact_angle_beta', 'film_vof_coupling_high',
         'film_vof_trans_high', 'film_vof_trans_high_relax',
         'film_vof_coupling_low', 'film_vof_trans_low',
         'film_vof_trans_low_relax', 'caf', 'thermal_stabilization',
         'scale_factor', 'stab_method', 'fensapice_flow_bc_subtype',
         'fensapice_ice_icing_mode', 'fensapice_ice_hflux',
         'fensapice_ice_hflux_1', 'fensapice_drop_vwet',
         'fensapice_dpm_wall_condition', 'fensapice_dpm_bc_norm_coeff',
         'fensapice_dpm_bc_tang_coeff']

    phase: phase_cls = phase_cls
    """
    phase child of wall_child.
    """
    name: name_cls = name_cls
    """
    name child of wall_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of wall_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of wall_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of wall_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of wall_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of wall_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of wall_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of wall_child.
    """
    d: d_cls = d_cls
    """
    d child of wall_child.
    """
    q_dot: q_dot_cls = q_dot_cls
    """
    q_dot child of wall_child.
    """
    material: material_cls = material_cls
    """
    material child of wall_child.
    """
    thermal_bc: thermal_bc_cls = thermal_bc_cls
    """
    thermal_bc child of wall_child.
    """
    t: t_cls = t_cls
    """
    t child of wall_child.
    """
    q: q_cls = q_cls
    """
    q child of wall_child.
    """
    h: h_cls = h_cls
    """
    h child of wall_child.
    """
    tinf: tinf_cls = tinf_cls
    """
    tinf child of wall_child.
    """
    planar_conduction: planar_conduction_cls = planar_conduction_cls
    """
    planar_conduction child of wall_child.
    """
    shell_conduction: shell_conduction_cls = shell_conduction_cls
    """
    shell_conduction child of wall_child.
    """
    thin_wall: thin_wall_cls = thin_wall_cls
    """
    thin_wall child of wall_child.
    """
    motion_bc: motion_bc_cls = motion_bc_cls
    """
    motion_bc child of wall_child.
    """
    shear_bc: shear_bc_cls = shear_bc_cls
    """
    shear_bc child of wall_child.
    """
    rough_bc: rough_bc_cls = rough_bc_cls
    """
    rough_bc child of wall_child.
    """
    moving: moving_cls = moving_cls
    """
    moving child of wall_child.
    """
    relative: relative_cls = relative_cls
    """
    relative child of wall_child.
    """
    rotating: rotating_cls = rotating_cls
    """
    rotating child of wall_child.
    """
    vmag: vmag_cls = vmag_cls
    """
    vmag child of wall_child.
    """
    wall_translation: wall_translation_cls = wall_translation_cls
    """
    wall_translation child of wall_child.
    """
    components: components_cls = components_cls
    """
    components child of wall_child.
    """
    velocity: velocity_cls = velocity_cls
    """
    velocity child of wall_child.
    """
    in_emiss: in_emiss_cls = in_emiss_cls
    """
    in_emiss child of wall_child.
    """
    ex_emiss: ex_emiss_cls = ex_emiss_cls
    """
    ex_emiss child of wall_child.
    """
    trad: trad_cls = trad_cls
    """
    trad child of wall_child.
    """
    int_rad: int_rad_cls = int_rad_cls
    """
    int_rad child of wall_child.
    """
    trad_internal: trad_internal_cls = trad_internal_cls
    """
    trad_internal child of wall_child.
    """
    area_enhancement_factor: area_enhancement_factor_cls = area_enhancement_factor_cls
    """
    area_enhancement_factor child of wall_child.
    """
    rough_option: rough_option_cls = rough_option_cls
    """
    rough_option child of wall_child.
    """
    rough_nasa: rough_nasa_cls = rough_nasa_cls
    """
    rough_nasa child of wall_child.
    """
    rough_shin_et_al: rough_shin_et_al_cls = rough_shin_et_al_cls
    """
    rough_shin_et_al child of wall_child.
    """
    rough_data: rough_data_cls = rough_data_cls
    """
    rough_data child of wall_child.
    """
    roughness_height: roughness_height_cls = roughness_height_cls
    """
    roughness_height child of wall_child.
    """
    roughness_const: roughness_const_cls = roughness_const_cls
    """
    roughness_const child of wall_child.
    """
    roughness_height_cp: roughness_height_cp_cls = roughness_height_cp_cls
    """
    roughness_height_cp child of wall_child.
    """
    roughness_const_cp: roughness_const_cp_cls = roughness_const_cp_cls
    """
    roughness_const_cp child of wall_child.
    """
    roughness_const_nasa: roughness_const_nasa_cls = roughness_const_nasa_cls
    """
    roughness_const_nasa child of wall_child.
    """
    roughness_const_shin: roughness_const_shin_cls = roughness_const_shin_cls
    """
    roughness_const_shin child of wall_child.
    """
    roughness_const_data: roughness_const_data_cls = roughness_const_data_cls
    """
    roughness_const_data child of wall_child.
    """
    variable_roughness: variable_roughness_cls = variable_roughness_cls
    """
    variable_roughness child of wall_child.
    """
    free_stream_velocity: free_stream_velocity_cls = free_stream_velocity_cls
    """
    free_stream_velocity child of wall_child.
    """
    free_stream_temp: free_stream_temp_cls = free_stream_temp_cls
    """
    free_stream_temp child of wall_child.
    """
    characteristic_length: characteristic_length_cls = characteristic_length_cls
    """
    characteristic_length child of wall_child.
    """
    free_stream_temp_cp: free_stream_temp_cp_cls = free_stream_temp_cp_cls
    """
    free_stream_temp_cp child of wall_child.
    """
    characteristic_length_cp: characteristic_length_cp_cls = characteristic_length_cp_cls
    """
    characteristic_length_cp child of wall_child.
    """
    liquid_content: liquid_content_cls = liquid_content_cls
    """
    liquid_content child of wall_child.
    """
    liquid_content_cp: liquid_content_cp_cls = liquid_content_cp_cls
    """
    liquid_content_cp child of wall_child.
    """
    droplet_diameter: droplet_diameter_cls = droplet_diameter_cls
    """
    droplet_diameter child of wall_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of wall_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of wall_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of wall_child.
    """
    dpm_bc_norm_coeff: dpm_bc_norm_coeff_cls = dpm_bc_norm_coeff_cls
    """
    dpm_bc_norm_coeff child of wall_child.
    """
    dpm_bc_tang_coeff: dpm_bc_tang_coeff_cls = dpm_bc_tang_coeff_cls
    """
    dpm_bc_tang_coeff child of wall_child.
    """
    dpm_bc_frictn_coeff: dpm_bc_frictn_coeff_cls = dpm_bc_frictn_coeff_cls
    """
    dpm_bc_frictn_coeff child of wall_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of wall_child.
    """
    dpm_film_splash_nsamp: dpm_film_splash_nsamp_cls = dpm_film_splash_nsamp_cls
    """
    dpm_film_splash_nsamp child of wall_child.
    """
    dpm_crit_temp_option: dpm_crit_temp_option_cls = dpm_crit_temp_option_cls
    """
    dpm_crit_temp_option child of wall_child.
    """
    dpm_critical_temp_factor: dpm_critical_temp_factor_cls = dpm_critical_temp_factor_cls
    """
    dpm_critical_temp_factor child of wall_child.
    """
    dpm_calibratable_temp: dpm_calibratable_temp_cls = dpm_calibratable_temp_cls
    """
    dpm_calibratable_temp child of wall_child.
    """
    dpm_impingement_splashing_model: dpm_impingement_splashing_model_cls = dpm_impingement_splashing_model_cls
    """
    dpm_impingement_splashing_model child of wall_child.
    """
    dpm_upper_deposition_limit_offset: dpm_upper_deposition_limit_offset_cls = dpm_upper_deposition_limit_offset_cls
    """
    dpm_upper_deposition_limit_offset child of wall_child.
    """
    dpm_deposition_delta_t: dpm_deposition_delta_t_cls = dpm_deposition_delta_t_cls
    """
    dpm_deposition_delta_t child of wall_child.
    """
    dpm_laplace_number_constant: dpm_laplace_number_constant_cls = dpm_laplace_number_constant_cls
    """
    dpm_laplace_number_constant child of wall_child.
    """
    dpm_partial_evaporation_ratio: dpm_partial_evaporation_ratio_cls = dpm_partial_evaporation_ratio_cls
    """
    dpm_partial_evaporation_ratio child of wall_child.
    """
    ra_roughness: ra_roughness_cls = ra_roughness_cls
    """
    ra_roughness child of wall_child.
    """
    rz_roughness: rz_roughness_cls = rz_roughness_cls
    """
    rz_roughness child of wall_child.
    """
    rq_roughness: rq_roughness_cls = rq_roughness_cls
    """
    rq_roughness child of wall_child.
    """
    rsm_roughness: rsm_roughness_cls = rsm_roughness_cls
    """
    rsm_roughness child of wall_child.
    """
    dpm_bc_erosion_generic: dpm_bc_erosion_generic_cls = dpm_bc_erosion_generic_cls
    """
    dpm_bc_erosion_generic child of wall_child.
    """
    dpm_bc_erosion: dpm_bc_erosion_cls = dpm_bc_erosion_cls
    """
    dpm_bc_erosion child of wall_child.
    """
    dpm_bc_erosion_c: dpm_bc_erosion_c_cls = dpm_bc_erosion_c_cls
    """
    dpm_bc_erosion_c child of wall_child.
    """
    dpm_bc_erosion_n: dpm_bc_erosion_n_cls = dpm_bc_erosion_n_cls
    """
    dpm_bc_erosion_n child of wall_child.
    """
    dpm_bc_erosion_finnie: dpm_bc_erosion_finnie_cls = dpm_bc_erosion_finnie_cls
    """
    dpm_bc_erosion_finnie child of wall_child.
    """
    dpm_bc_erosion_finnie_k: dpm_bc_erosion_finnie_k_cls = dpm_bc_erosion_finnie_k_cls
    """
    dpm_bc_erosion_finnie_k child of wall_child.
    """
    dpm_bc_erosion_finnie_vel_exp: dpm_bc_erosion_finnie_vel_exp_cls = dpm_bc_erosion_finnie_vel_exp_cls
    """
    dpm_bc_erosion_finnie_vel_exp child of wall_child.
    """
    dpm_bc_erosion_finnie_max_erosion_angle: dpm_bc_erosion_finnie_max_erosion_angle_cls = dpm_bc_erosion_finnie_max_erosion_angle_cls
    """
    dpm_bc_erosion_finnie_max_erosion_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury: dpm_bc_erosion_mclaury_cls = dpm_bc_erosion_mclaury_cls
    """
    dpm_bc_erosion_mclaury child of wall_child.
    """
    dpm_bc_erosion_mclaury_a: dpm_bc_erosion_mclaury_a_cls = dpm_bc_erosion_mclaury_a_cls
    """
    dpm_bc_erosion_mclaury_a child of wall_child.
    """
    dpm_bc_erosion_mclaury_vel_exp: dpm_bc_erosion_mclaury_vel_exp_cls = dpm_bc_erosion_mclaury_vel_exp_cls
    """
    dpm_bc_erosion_mclaury_vel_exp child of wall_child.
    """
    dpm_bc_erosion_mclaury_transition_angle: dpm_bc_erosion_mclaury_transition_angle_cls = dpm_bc_erosion_mclaury_transition_angle_cls
    """
    dpm_bc_erosion_mclaury_transition_angle child of wall_child.
    """
    dpm_bc_erosion_mclaury_b: dpm_bc_erosion_mclaury_b_cls = dpm_bc_erosion_mclaury_b_cls
    """
    dpm_bc_erosion_mclaury_b child of wall_child.
    """
    dpm_bc_erosion_mclaury_c: dpm_bc_erosion_mclaury_c_cls = dpm_bc_erosion_mclaury_c_cls
    """
    dpm_bc_erosion_mclaury_c child of wall_child.
    """
    dpm_bc_erosion_mclaury_w: dpm_bc_erosion_mclaury_w_cls = dpm_bc_erosion_mclaury_w_cls
    """
    dpm_bc_erosion_mclaury_w child of wall_child.
    """
    dpm_bc_erosion_mclaury_x: dpm_bc_erosion_mclaury_x_cls = dpm_bc_erosion_mclaury_x_cls
    """
    dpm_bc_erosion_mclaury_x child of wall_child.
    """
    dpm_bc_erosion_mclaury_y: dpm_bc_erosion_mclaury_y_cls = dpm_bc_erosion_mclaury_y_cls
    """
    dpm_bc_erosion_mclaury_y child of wall_child.
    """
    dpm_bc_erosion_oka: dpm_bc_erosion_oka_cls = dpm_bc_erosion_oka_cls
    """
    dpm_bc_erosion_oka child of wall_child.
    """
    dpm_bc_erosion_oka_e90: dpm_bc_erosion_oka_e90_cls = dpm_bc_erosion_oka_e90_cls
    """
    dpm_bc_erosion_oka_e90 child of wall_child.
    """
    dpm_bc_erosion_oka_hv: dpm_bc_erosion_oka_hv_cls = dpm_bc_erosion_oka_hv_cls
    """
    dpm_bc_erosion_oka_hv child of wall_child.
    """
    dpm_bc_erosion_oka_n1: dpm_bc_erosion_oka_n1_cls = dpm_bc_erosion_oka_n1_cls
    """
    dpm_bc_erosion_oka_n1 child of wall_child.
    """
    dpm_bc_erosion_oka_n2: dpm_bc_erosion_oka_n2_cls = dpm_bc_erosion_oka_n2_cls
    """
    dpm_bc_erosion_oka_n2 child of wall_child.
    """
    dpm_bc_erosion_oka_k2: dpm_bc_erosion_oka_k2_cls = dpm_bc_erosion_oka_k2_cls
    """
    dpm_bc_erosion_oka_k2 child of wall_child.
    """
    dpm_bc_erosion_oka_k3: dpm_bc_erosion_oka_k3_cls = dpm_bc_erosion_oka_k3_cls
    """
    dpm_bc_erosion_oka_k3 child of wall_child.
    """
    dpm_bc_erosion_oka_dref: dpm_bc_erosion_oka_dref_cls = dpm_bc_erosion_oka_dref_cls
    """
    dpm_bc_erosion_oka_dref child of wall_child.
    """
    dpm_bc_erosion_oka_vref: dpm_bc_erosion_oka_vref_cls = dpm_bc_erosion_oka_vref_cls
    """
    dpm_bc_erosion_oka_vref child of wall_child.
    """
    dpm_bc_erosion_dnv: dpm_bc_erosion_dnv_cls = dpm_bc_erosion_dnv_cls
    """
    dpm_bc_erosion_dnv child of wall_child.
    """
    dpm_bc_erosion_dnv_k: dpm_bc_erosion_dnv_k_cls = dpm_bc_erosion_dnv_k_cls
    """
    dpm_bc_erosion_dnv_k child of wall_child.
    """
    dpm_bc_erosion_dnv_n: dpm_bc_erosion_dnv_n_cls = dpm_bc_erosion_dnv_n_cls
    """
    dpm_bc_erosion_dnv_n child of wall_child.
    """
    dpm_bc_erosion_dnv_ductile: dpm_bc_erosion_dnv_ductile_cls = dpm_bc_erosion_dnv_ductile_cls
    """
    dpm_bc_erosion_dnv_ductile child of wall_child.
    """
    dpm_bc_erosion_shear: dpm_bc_erosion_shear_cls = dpm_bc_erosion_shear_cls
    """
    dpm_bc_erosion_shear child of wall_child.
    """
    dpm_bc_erosion_shear_v: dpm_bc_erosion_shear_v_cls = dpm_bc_erosion_shear_v_cls
    """
    dpm_bc_erosion_shear_v child of wall_child.
    """
    dpm_bc_erosion_shear_c: dpm_bc_erosion_shear_c_cls = dpm_bc_erosion_shear_c_cls
    """
    dpm_bc_erosion_shear_c child of wall_child.
    """
    dpm_bc_erosion_shear_packing_limit: dpm_bc_erosion_shear_packing_limit_cls = dpm_bc_erosion_shear_packing_limit_cls
    """
    dpm_bc_erosion_shear_packing_limit child of wall_child.
    """
    dpm_bc_erosion_shielding: dpm_bc_erosion_shielding_cls = dpm_bc_erosion_shielding_cls
    """
    dpm_bc_erosion_shielding child of wall_child.
    """
    dpm_wall_heat_exchange: dpm_wall_heat_exchange_cls = dpm_wall_heat_exchange_cls
    """
    dpm_wall_heat_exchange child of wall_child.
    """
    dpm_film_condensation: dpm_film_condensation_cls = dpm_film_condensation_cls
    """
    dpm_film_condensation child of wall_child.
    """
    dpm_film_bl_model: dpm_film_bl_model_cls = dpm_film_bl_model_cls
    """
    dpm_film_bl_model child of wall_child.
    """
    dpm_particle_stripping: dpm_particle_stripping_cls = dpm_particle_stripping_cls
    """
    dpm_particle_stripping child of wall_child.
    """
    dpm_critical_shear_stress: dpm_critical_shear_stress_cls = dpm_critical_shear_stress_cls
    """
    dpm_critical_shear_stress child of wall_child.
    """
    dpm_film_separation_model: dpm_film_separation_model_cls = dpm_film_separation_model_cls
    """
    dpm_film_separation_model child of wall_child.
    """
    dpm_critical_we_number: dpm_critical_we_number_cls = dpm_critical_we_number_cls
    """
    dpm_critical_we_number child of wall_child.
    """
    dpm_film_separation_angle: dpm_film_separation_angle_cls = dpm_film_separation_angle_cls
    """
    dpm_film_separation_angle child of wall_child.
    """
    dpm_allow_lwf_to_vof: dpm_allow_lwf_to_vof_cls = dpm_allow_lwf_to_vof_cls
    """
    dpm_allow_lwf_to_vof child of wall_child.
    """
    dpm_allow_vof_to_lwf: dpm_allow_vof_to_lwf_cls = dpm_allow_vof_to_lwf_cls
    """
    dpm_allow_vof_to_lwf child of wall_child.
    """
    dpm_initialize_lwf: dpm_initialize_lwf_cls = dpm_initialize_lwf_cls
    """
    dpm_initialize_lwf child of wall_child.
    """
    dpm_initial_height: dpm_initial_height_cls = dpm_initial_height_cls
    """
    dpm_initial_height child of wall_child.
    """
    film_velocity: film_velocity_cls = film_velocity_cls
    """
    film_velocity child of wall_child.
    """
    dpm_initial_temperature: dpm_initial_temperature_cls = dpm_initial_temperature_cls
    """
    dpm_initial_temperature child of wall_child.
    """
    dpm_initial_injection: dpm_initial_injection_cls = dpm_initial_injection_cls
    """
    dpm_initial_injection child of wall_child.
    """
    film_parcel_surface_area_density: film_parcel_surface_area_density_cls = film_parcel_surface_area_density_cls
    """
    film_parcel_surface_area_density child of wall_child.
    """
    minimum_number_of_parcels_per_face: minimum_number_of_parcels_per_face_cls = minimum_number_of_parcels_per_face_cls
    """
    minimum_number_of_parcels_per_face child of wall_child.
    """
    band_in_emiss: band_in_emiss_cls = band_in_emiss_cls
    """
    band_in_emiss child of wall_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of wall_child.
    """
    mc_bsource_p: mc_bsource_p_cls = mc_bsource_p_cls
    """
    mc_bsource_p child of wall_child.
    """
    mc_poldfun_p: mc_poldfun_p_cls = mc_poldfun_p_cls
    """
    mc_poldfun_p child of wall_child.
    """
    polar_func_type: polar_func_type_cls = polar_func_type_cls
    """
    polar_func_type child of wall_child.
    """
    mc_polar_expr: mc_polar_expr_cls = mc_polar_expr_cls
    """
    mc_polar_expr child of wall_child.
    """
    polar_pair_list: polar_pair_list_cls = polar_pair_list_cls
    """
    polar_pair_list child of wall_child.
    """
    pold_pair_list_rad: pold_pair_list_rad_cls = pold_pair_list_rad_cls
    """
    pold_pair_list_rad child of wall_child.
    """
    radiation_direction: radiation_direction_cls = radiation_direction_cls
    """
    radiation_direction child of wall_child.
    """
    coll_dtheta: coll_dtheta_cls = coll_dtheta_cls
    """
    coll_dtheta child of wall_child.
    """
    coll_dphi: coll_dphi_cls = coll_dphi_cls
    """
    coll_dphi child of wall_child.
    """
    band_q_irrad: band_q_irrad_cls = band_q_irrad_cls
    """
    band_q_irrad child of wall_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = band_q_irrad_diffuse_cls
    """
    band_q_irrad_diffuse child of wall_child.
    """
    band_diffuse_frac: band_diffuse_frac_cls = band_diffuse_frac_cls
    """
    band_diffuse_frac child of wall_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of wall_child.
    """
    critical_zone: critical_zone_cls = critical_zone_cls
    """
    critical_zone child of wall_child.
    """
    fpsc: fpsc_cls = fpsc_cls
    """
    fpsc child of wall_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of wall_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of wall_child.
    """
    solar_direction: solar_direction_cls = solar_direction_cls
    """
    solar_direction child of wall_child.
    """
    solar_irradiation: solar_irradiation_cls = solar_irradiation_cls
    """
    solar_irradiation child of wall_child.
    """
    v_transmissivity: v_transmissivity_cls = v_transmissivity_cls
    """
    v_transmissivity child of wall_child.
    """
    ir_transmissivity: ir_transmissivity_cls = ir_transmissivity_cls
    """
    ir_transmissivity child of wall_child.
    """
    v_opq_absorbtivity: v_opq_absorbtivity_cls = v_opq_absorbtivity_cls
    """
    v_opq_absorbtivity child of wall_child.
    """
    ir_opq_absorbtivity: ir_opq_absorbtivity_cls = ir_opq_absorbtivity_cls
    """
    ir_opq_absorbtivity child of wall_child.
    """
    v_st_absorbtivity: v_st_absorbtivity_cls = v_st_absorbtivity_cls
    """
    v_st_absorbtivity child of wall_child.
    """
    ir_st_absorbtivity: ir_st_absorbtivity_cls = ir_st_absorbtivity_cls
    """
    ir_st_absorbtivity child of wall_child.
    """
    d_st_absorbtivity: d_st_absorbtivity_cls = d_st_absorbtivity_cls
    """
    d_st_absorbtivity child of wall_child.
    """
    d_transmissivity: d_transmissivity_cls = d_transmissivity_cls
    """
    d_transmissivity child of wall_child.
    """
    fsi_interface: fsi_interface_cls = fsi_interface_cls
    """
    fsi_interface child of wall_child.
    """
    react: react_cls = react_cls
    """
    react child of wall_child.
    """
    partially_catalytic: partially_catalytic_cls = partially_catalytic_cls
    """
    partially_catalytic child of wall_child.
    """
    partially_catalytic_material: partially_catalytic_material_cls = partially_catalytic_material_cls
    """
    partially_catalytic_material child of wall_child.
    """
    partially_catalytic_recombination_coefficient_o: partially_catalytic_recombination_coefficient_o_cls = partially_catalytic_recombination_coefficient_o_cls
    """
    partially_catalytic_recombination_coefficient_o child of wall_child.
    """
    partially_catalytic_recombination_coefficient_n: partially_catalytic_recombination_coefficient_n_cls = partially_catalytic_recombination_coefficient_n_cls
    """
    partially_catalytic_recombination_coefficient_n child of wall_child.
    """
    partially_catalytic_recombination_model: partially_catalytic_recombination_model_cls = partially_catalytic_recombination_model_cls
    """
    partially_catalytic_recombination_model child of wall_child.
    """
    species_spec: species_spec_cls = species_spec_cls
    """
    species_spec child of wall_child.
    """
    mf: mf_cls = mf_cls
    """
    mf child of wall_child.
    """
    elec_potential_type: elec_potential_type_cls = elec_potential_type_cls
    """
    elec_potential_type child of wall_child.
    """
    potential_value: potential_value_cls = potential_value_cls
    """
    potential_value child of wall_child.
    """
    elec_potential_jump: elec_potential_jump_cls = elec_potential_jump_cls
    """
    elec_potential_jump child of wall_child.
    """
    elec_potential_resistance: elec_potential_resistance_cls = elec_potential_resistance_cls
    """
    elec_potential_resistance child of wall_child.
    """
    dual_potential_type: dual_potential_type_cls = dual_potential_type_cls
    """
    dual_potential_type child of wall_child.
    """
    dual_potential_value: dual_potential_value_cls = dual_potential_value_cls
    """
    dual_potential_value child of wall_child.
    """
    echem_reaction: echem_reaction_cls = echem_reaction_cls
    """
    echem_reaction child of wall_child.
    """
    elec_potential_mechs: elec_potential_mechs_cls = elec_potential_mechs_cls
    """
    elec_potential_mechs child of wall_child.
    """
    faradaic_heat: faradaic_heat_cls = faradaic_heat_cls
    """
    faradaic_heat child of wall_child.
    """
    li_ion_type: li_ion_type_cls = li_ion_type_cls
    """
    li_ion_type child of wall_child.
    """
    li_ion_value: li_ion_value_cls = li_ion_value_cls
    """
    li_ion_value child of wall_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of wall_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of wall_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of wall_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of wall_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of wall_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of wall_child.
    """
    per_dispx: per_dispx_cls = per_dispx_cls
    """
    per_dispx child of wall_child.
    """
    per_dispy: per_dispy_cls = per_dispy_cls
    """
    per_dispy child of wall_child.
    """
    per_dispz: per_dispz_cls = per_dispz_cls
    """
    per_dispz child of wall_child.
    """
    per_imagx: per_imagx_cls = per_imagx_cls
    """
    per_imagx child of wall_child.
    """
    per_imagy: per_imagy_cls = per_imagy_cls
    """
    per_imagy child of wall_child.
    """
    per_imagz: per_imagz_cls = per_imagz_cls
    """
    per_imagz child of wall_child.
    """
    freq: freq_cls = freq_cls
    """
    freq child of wall_child.
    """
    amp: amp_cls = amp_cls
    """
    amp child of wall_child.
    """
    nodal_diam: nodal_diam_cls = nodal_diam_cls
    """
    nodal_diam child of wall_child.
    """
    pass_number: pass_number_cls = pass_number_cls
    """
    pass_number child of wall_child.
    """
    fwd: fwd_cls = fwd_cls
    """
    fwd child of wall_child.
    """
    aero: aero_cls = aero_cls
    """
    aero child of wall_child.
    """
    cmplx: cmplx_cls = cmplx_cls
    """
    cmplx child of wall_child.
    """
    norm: norm_cls = norm_cls
    """
    norm child of wall_child.
    """
    method: method_cls = method_cls
    """
    method child of wall_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of wall_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of wall_child.
    """
    gtemp_bc: gtemp_bc_cls = gtemp_bc_cls
    """
    gtemp_bc child of wall_child.
    """
    g_temperature: g_temperature_cls = g_temperature_cls
    """
    g_temperature child of wall_child.
    """
    g_qflux: g_qflux_cls = g_qflux_cls
    """
    g_qflux child of wall_child.
    """
    wall_restitution_coeff: wall_restitution_coeff_cls = wall_restitution_coeff_cls
    """
    wall_restitution_coeff child of wall_child.
    """
    omega: omega_cls = omega_cls
    """
    omega child of wall_child.
    """
    rotation_axis_origin: rotation_axis_origin_cls = rotation_axis_origin_cls
    """
    rotation_axis_origin child of wall_child.
    """
    rotation_axis_direction: rotation_axis_direction_cls = rotation_axis_direction_cls
    """
    rotation_axis_direction child of wall_child.
    """
    adhesion_angle: adhesion_angle_cls = adhesion_angle_cls
    """
    adhesion_angle child of wall_child.
    """
    specified_shear: specified_shear_cls = specified_shear_cls
    """
    specified_shear child of wall_child.
    """
    shear_stress: shear_stress_cls = shear_stress_cls
    """
    shear_stress child of wall_child.
    """
    fslip: fslip_cls = fslip_cls
    """
    fslip child of wall_child.
    """
    eslip: eslip_cls = eslip_cls
    """
    eslip child of wall_child.
    """
    surf_tens_grad: surf_tens_grad_cls = surf_tens_grad_cls
    """
    surf_tens_grad child of wall_child.
    """
    contact_resistance: contact_resistance_cls = contact_resistance_cls
    """
    contact_resistance child of wall_child.
    """
    reaction_mechs: reaction_mechs_cls = reaction_mechs_cls
    """
    reaction_mechs child of wall_child.
    """
    surf_washcoat_factor: surf_washcoat_factor_cls = surf_washcoat_factor_cls
    """
    surf_washcoat_factor child of wall_child.
    """
    initial_deposition_height: initial_deposition_height_cls = initial_deposition_height_cls
    """
    initial_deposition_height child of wall_child.
    """
    solid_species_density: solid_species_density_cls = solid_species_density_cls
    """
    solid_species_density child of wall_child.
    """
    ablation_select_model: ablation_select_model_cls = ablation_select_model_cls
    """
    ablation_select_model child of wall_child.
    """
    ablation_vielle_a: ablation_vielle_a_cls = ablation_vielle_a_cls
    """
    ablation_vielle_a child of wall_child.
    """
    ablation_vielle_n: ablation_vielle_n_cls = ablation_vielle_n_cls
    """
    ablation_vielle_n child of wall_child.
    """
    ablation_flux: ablation_flux_cls = ablation_flux_cls
    """
    ablation_flux child of wall_child.
    """
    ablation_surfacerxn_density: ablation_surfacerxn_density_cls = ablation_surfacerxn_density_cls
    """
    ablation_surfacerxn_density child of wall_child.
    """
    ablation_species_mf: ablation_species_mf_cls = ablation_species_mf_cls
    """
    ablation_species_mf child of wall_child.
    """
    specular_coeff: specular_coeff_cls = specular_coeff_cls
    """
    specular_coeff child of wall_child.
    """
    mom_accom_coef: mom_accom_coef_cls = mom_accom_coef_cls
    """
    mom_accom_coef child of wall_child.
    """
    therm_accom_coef: therm_accom_coef_cls = therm_accom_coef_cls
    """
    therm_accom_coef child of wall_child.
    """
    eve_accom_coef: eve_accom_coef_cls = eve_accom_coef_cls
    """
    eve_accom_coef child of wall_child.
    """
    film_wall: film_wall_cls = film_wall_cls
    """
    film_wall child of wall_child.
    """
    film_wall_bc: film_wall_bc_cls = film_wall_bc_cls
    """
    film_wall_bc child of wall_child.
    """
    film_height: film_height_cls = film_height_cls
    """
    film_height child of wall_child.
    """
    flux_momentum: flux_momentum_cls = flux_momentum_cls
    """
    flux_momentum child of wall_child.
    """
    film_relative_vel: film_relative_vel_cls = film_relative_vel_cls
    """
    film_relative_vel child of wall_child.
    """
    film_bc_imp_press: film_bc_imp_press_cls = film_bc_imp_press_cls
    """
    film_bc_imp_press child of wall_child.
    """
    film_temperature: film_temperature_cls = film_temperature_cls
    """
    film_temperature child of wall_child.
    """
    film_scalar: film_scalar_cls = film_scalar_cls
    """
    film_scalar child of wall_child.
    """
    film_source: film_source_cls = film_source_cls
    """
    film_source child of wall_child.
    """
    film_h_src: film_h_src_cls = film_h_src_cls
    """
    film_h_src child of wall_child.
    """
    momentum_source: momentum_source_cls = momentum_source_cls
    """
    momentum_source child of wall_child.
    """
    film_t_src: film_t_src_cls = film_t_src_cls
    """
    film_t_src child of wall_child.
    """
    film_s_src: film_s_src_cls = film_s_src_cls
    """
    film_s_src child of wall_child.
    """
    film_phase_change: film_phase_change_cls = film_phase_change_cls
    """
    film_phase_change child of wall_child.
    """
    film_phase_change_model: film_phase_change_model_cls = film_phase_change_model_cls
    """
    film_phase_change_model child of wall_child.
    """
    film_cond_const: film_cond_const_cls = film_cond_const_cls
    """
    film_cond_const child of wall_child.
    """
    film_vapo_const: film_vapo_const_cls = film_vapo_const_cls
    """
    film_vapo_const child of wall_child.
    """
    film_cond_rate: film_cond_rate_cls = film_cond_rate_cls
    """
    film_cond_rate child of wall_child.
    """
    film_vapo_rate: film_vapo_rate_cls = film_vapo_rate_cls
    """
    film_vapo_rate child of wall_child.
    """
    film_momentum_coupling: film_momentum_coupling_cls = film_momentum_coupling_cls
    """
    film_momentum_coupling child of wall_child.
    """
    film_splash_wall: film_splash_wall_cls = film_splash_wall_cls
    """
    film_splash_wall child of wall_child.
    """
    film_boundary_separation: film_boundary_separation_cls = film_boundary_separation_cls
    """
    film_boundary_separation child of wall_child.
    """
    film_impinge_model: film_impinge_model_cls = film_impinge_model_cls
    """
    film_impinge_model child of wall_child.
    """
    film_splash_nparc: film_splash_nparc_cls = film_splash_nparc_cls
    """
    film_splash_nparc child of wall_child.
    """
    film_crit_temp_factor: film_crit_temp_factor_cls = film_crit_temp_factor_cls
    """
    film_crit_temp_factor child of wall_child.
    """
    film_roughness_ra: film_roughness_ra_cls = film_roughness_ra_cls
    """
    film_roughness_ra child of wall_child.
    """
    film_roughness_rz: film_roughness_rz_cls = film_roughness_rz_cls
    """
    film_roughness_rz child of wall_child.
    """
    film_upper_deposition_limit_offset: film_upper_deposition_limit_offset_cls = film_upper_deposition_limit_offset_cls
    """
    film_upper_deposition_limit_offset child of wall_child.
    """
    film_deposition_delta_t: film_deposition_delta_t_cls = film_deposition_delta_t_cls
    """
    film_deposition_delta_t child of wall_child.
    """
    film_laplace_number_constant: film_laplace_number_constant_cls = film_laplace_number_constant_cls
    """
    film_laplace_number_constant child of wall_child.
    """
    film_partial_evap_ratio: film_partial_evap_ratio_cls = film_partial_evap_ratio_cls
    """
    film_partial_evap_ratio child of wall_child.
    """
    film_contact_angle: film_contact_angle_cls = film_contact_angle_cls
    """
    film_contact_angle child of wall_child.
    """
    film_contact_angle_mean: film_contact_angle_mean_cls = film_contact_angle_mean_cls
    """
    film_contact_angle_mean child of wall_child.
    """
    film_contact_angle_rstd: film_contact_angle_rstd_cls = film_contact_angle_rstd_cls
    """
    film_contact_angle_rstd child of wall_child.
    """
    film_contact_angle_beta: film_contact_angle_beta_cls = film_contact_angle_beta_cls
    """
    film_contact_angle_beta child of wall_child.
    """
    film_vof_coupling_high: film_vof_coupling_high_cls = film_vof_coupling_high_cls
    """
    film_vof_coupling_high child of wall_child.
    """
    film_vof_trans_high: film_vof_trans_high_cls = film_vof_trans_high_cls
    """
    film_vof_trans_high child of wall_child.
    """
    film_vof_trans_high_relax: film_vof_trans_high_relax_cls = film_vof_trans_high_relax_cls
    """
    film_vof_trans_high_relax child of wall_child.
    """
    film_vof_coupling_low: film_vof_coupling_low_cls = film_vof_coupling_low_cls
    """
    film_vof_coupling_low child of wall_child.
    """
    film_vof_trans_low: film_vof_trans_low_cls = film_vof_trans_low_cls
    """
    film_vof_trans_low child of wall_child.
    """
    film_vof_trans_low_relax: film_vof_trans_low_relax_cls = film_vof_trans_low_relax_cls
    """
    film_vof_trans_low_relax child of wall_child.
    """
    caf: caf_cls = caf_cls
    """
    caf child of wall_child.
    """
    thermal_stabilization: thermal_stabilization_cls = thermal_stabilization_cls
    """
    thermal_stabilization child of wall_child.
    """
    scale_factor: scale_factor_cls = scale_factor_cls
    """
    scale_factor child of wall_child.
    """
    stab_method: stab_method_cls = stab_method_cls
    """
    stab_method child of wall_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = fensapice_flow_bc_subtype_cls
    """
    fensapice_flow_bc_subtype child of wall_child.
    """
    fensapice_ice_icing_mode: fensapice_ice_icing_mode_cls = fensapice_ice_icing_mode_cls
    """
    fensapice_ice_icing_mode child of wall_child.
    """
    fensapice_ice_hflux: fensapice_ice_hflux_cls = fensapice_ice_hflux_cls
    """
    fensapice_ice_hflux child of wall_child.
    """
    fensapice_ice_hflux_1: fensapice_ice_hflux_1_cls = fensapice_ice_hflux_1_cls
    """
    fensapice_ice_hflux_1 child of wall_child.
    """
    fensapice_drop_vwet: fensapice_drop_vwet_cls = fensapice_drop_vwet_cls
    """
    fensapice_drop_vwet child of wall_child.
    """
    fensapice_dpm_wall_condition: fensapice_dpm_wall_condition_cls = fensapice_dpm_wall_condition_cls
    """
    fensapice_dpm_wall_condition child of wall_child.
    """
    fensapice_dpm_bc_norm_coeff: fensapice_dpm_bc_norm_coeff_cls = fensapice_dpm_bc_norm_coeff_cls
    """
    fensapice_dpm_bc_norm_coeff child of wall_child.
    """
    fensapice_dpm_bc_tang_coeff: fensapice_dpm_bc_tang_coeff_cls = fensapice_dpm_bc_tang_coeff_cls
    """
    fensapice_dpm_bc_tang_coeff child of wall_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .min_max import min_max as min_max_cls
from .in_range import in_range as in_range_cls
from .except_in_range import except_in_range as except_in_range_cls
from .top_value_cells import top_value_cells as top_value_cells_cls
from .low_value_cells import low_value_cells as low_value_cells_cls
from .less_than import less_than as less_than_cls
from .more_than import more_than as more_than_cls
from .between_std_dev import between_std_dev as between_std_dev_cls
from .outside_std_dev import outside_std_dev as outside_std_dev_cls
from .less_than_std_dev import less_than_std_dev as less_than_std_dev_cls
from .more_than_std_dev import more_than_std_dev as more_than_std_dev_cls
class option(Group):
    """
    'option' child.
    """

    fluent_name = "option"

    child_names = \
        ['option', 'min_max', 'in_range', 'except_in_range',
         'top_value_cells', 'low_value_cells', 'less_than', 'more_than',
         'between_std_dev', 'outside_std_dev', 'less_than_std_dev',
         'more_than_std_dev']

    option: option_cls = option_cls
    """
    option child of option.
    """
    min_max: min_max_cls = min_max_cls
    """
    min_max child of option.
    """
    in_range: in_range_cls = in_range_cls
    """
    in_range child of option.
    """
    except_in_range: except_in_range_cls = except_in_range_cls
    """
    except_in_range child of option.
    """
    top_value_cells: top_value_cells_cls = top_value_cells_cls
    """
    top_value_cells child of option.
    """
    low_value_cells: low_value_cells_cls = low_value_cells_cls
    """
    low_value_cells child of option.
    """
    less_than: less_than_cls = less_than_cls
    """
    less_than child of option.
    """
    more_than: more_than_cls = more_than_cls
    """
    more_than child of option.
    """
    between_std_dev: between_std_dev_cls = between_std_dev_cls
    """
    between_std_dev child of option.
    """
    outside_std_dev: outside_std_dev_cls = outside_std_dev_cls
    """
    outside_std_dev child of option.
    """
    less_than_std_dev: less_than_std_dev_cls = less_than_std_dev_cls
    """
    less_than_std_dev child of option.
    """
    more_than_std_dev: more_than_std_dev_cls = more_than_std_dev_cls
    """
    more_than_std_dev child of option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class continue_strategy_execution(Command):
    """
    Continue execution of the automatic initialization and case modification strategy defined at present.
    """

    fluent_name = "continue-strategy-execution"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable import enable as enable_cls
from .gradient_correction_mode import gradient_correction_mode as gradient_correction_mode_cls
class enable(Command):
    """
    Enable Warped-Face Gradient Correction.
    
    Parameters
    ----------
        enable : bool
            'enable' child.
        gradient_correction_mode : str
            'gradient_correction_mode' child.
    
    """

    fluent_name = "enable?"

    argument_names = \
        ['enable', 'gradient_correction_mode']

    enable: enable_cls = enable_cls
    """
    enable argument of enable.
    """
    gradient_correction_mode: gradient_correction_mode_cls = gradient_correction_mode_cls
    """
    gradient_correction_mode argument of enable.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .components_2 import components as components_cls
from .list_properties_4 import list_properties as list_properties_cls
class groups_child(Group):
    """
    'child_object_type' of groups.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['components']

    components: components_cls = components_cls
    """
    components child of groups_child.
    """
    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of groups_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .driver_name import driver_name as driver_name_cls
class driver(Command):
    """
    Change the current graphics driver.
    
    Parameters
    ----------
        driver_name : str
            'driver_name' child.
    
    """

    fluent_name = "driver"

    argument_names = \
        ['driver_name']

    driver_name: driver_name_cls = driver_name_cls
    """
    driver_name argument of driver.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .x_scale import x_scale as x_scale_cls
from .y_scale import y_scale as y_scale_cls
from .z_scale import z_scale as z_scale_cls
class scale(Command):
    """
    'scale' command.
    
    Parameters
    ----------
        x_scale : real
            'x_scale' child.
        y_scale : real
            'y_scale' child.
        z_scale : real
            'z_scale' child.
    
    """

    fluent_name = "scale"

    argument_names = \
        ['x_scale', 'y_scale', 'z_scale']

    x_scale: x_scale_cls = x_scale_cls
    """
    x_scale argument of scale.
    """
    y_scale: y_scale_cls = y_scale_cls
    """
    y_scale argument of scale.
    """
    z_scale: z_scale_cls = z_scale_cls
    """
    z_scale argument of scale.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_1 import zone_name as zone_name_cls
from .value_1 import value as value_cls
class contact_resis_child(Group):
    """
    'child_object_type' of contact_resis.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['zone_name', 'value']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name child of contact_resis_child.
    """
    value: value_cls = value_cls
    """
    value child of contact_resis_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cell_zone_name import cell_zone_name as cell_zone_name_cls
class mrf_to_sliding_mesh(Command):
    """
    Change motion specification from MRF to moving mesh.
    
    Parameters
    ----------
        cell_zone_name : str
            Enter a cell zone name.
    
    """

    fluent_name = "mrf-to-sliding-mesh"

    argument_names = \
        ['cell_zone_name']

    cell_zone_name: cell_zone_name_cls = cell_zone_name_cls
    """
    cell_zone_name argument of mrf_to_sliding_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class local_values_range_list(RealList):
    """
    'local_values_range_list' child.
    """

    fluent_name = "local-values-range-list"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class enforce_coupled_wall_between_solids(Boolean):
    """
    Create coupled wall interface between solids.
    """

    fluent_name = "enforce-coupled-wall-between-solids?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fmg_courant_number import fmg_courant_number as fmg_courant_number_cls
from .enable_fmg_verbose import enable_fmg_verbose as enable_fmg_verbose_cls
from .viscous_terms import viscous_terms as viscous_terms_cls
from .species_reactions import species_reactions as species_reactions_cls
from .turbulent_viscosity_ratio_3 import turbulent_viscosity_ratio as turbulent_viscosity_ratio_cls
from .fmg_initialize import fmg_initialize as fmg_initialize_cls
from .customize import customize as customize_cls
from .reset_to_defaults import reset_to_defaults as reset_to_defaults_cls
class fmg(Group):
    """
    Enter the set full-multigrid for initialization menu.
    """

    fluent_name = "fmg"

    child_names = \
        ['fmg_courant_number', 'enable_fmg_verbose', 'viscous_terms',
         'species_reactions', 'turbulent_viscosity_ratio']

    fmg_courant_number: fmg_courant_number_cls = fmg_courant_number_cls
    """
    fmg_courant_number child of fmg.
    """
    enable_fmg_verbose: enable_fmg_verbose_cls = enable_fmg_verbose_cls
    """
    enable_fmg_verbose child of fmg.
    """
    viscous_terms: viscous_terms_cls = viscous_terms_cls
    """
    viscous_terms child of fmg.
    """
    species_reactions: species_reactions_cls = species_reactions_cls
    """
    species_reactions child of fmg.
    """
    turbulent_viscosity_ratio: turbulent_viscosity_ratio_cls = turbulent_viscosity_ratio_cls
    """
    turbulent_viscosity_ratio child of fmg.
    """
    command_names = \
        ['fmg_initialize', 'customize', 'reset_to_defaults']

    fmg_initialize: fmg_initialize_cls = fmg_initialize_cls
    """
    fmg_initialize command of fmg.
    """
    customize: customize_cls = customize_cls
    """
    customize command of fmg.
    """
    reset_to_defaults: reset_to_defaults_cls = reset_to_defaults_cls
    """
    reset_to_defaults command of fmg.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .sc_enable_sub_stepping_option_per_coupling_step import sc_enable_sub_stepping_option_per_coupling_step as sc_enable_sub_stepping_option_per_coupling_step_cls
class unsteady_statistics(Group):
    """
    Enter the unsteady statistics menu.
    """

    fluent_name = "unsteady-statistics"

    command_names = \
        ['sc_enable_sub_stepping_option_per_coupling_step']

    sc_enable_sub_stepping_option_per_coupling_step: sc_enable_sub_stepping_option_per_coupling_step_cls = sc_enable_sub_stepping_option_per_coupling_step_cls
    """
    sc_enable_sub_stepping_option_per_coupling_step command of unsteady_statistics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class design_points:
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def list_properties(self, object_name: str):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def duplicate(self, design_point: str):
        """
        Duplicate Design Point.
        
        Parameters
        ----------
            design_point : str
                'design_point' child.
        
        """

    def create_1(self, write_data: bool, capture_simulation_report_data: bool):
        """
        Add new Design Point.
        
        Parameters
        ----------
            write_data : bool
                'write_data' child.
            capture_simulation_report_data : bool
                'capture_simulation_report_data' child.
        
        """

    def load_case_data(self, ):
        """
        Loads relevant case/data file for current design point.
        """

    def set_as_current(self, design_point: str):
        """
        Set current design point.
        
        Parameters
        ----------
            design_point : str
                'design_point' child.
        
        """

    def delete_design_points(self, design_points: List[str]):
        """
        Delete Design Points.
        
        Parameters
        ----------
            design_points : typing.List[str]
                'design_points' child.
        
        """

    def save_journals(self, separate_journals: bool):
        """
        Save Journals.
        
        Parameters
        ----------
            separate_journals : bool
                'separate_journals' child.
        
        """

    def clear_generated_data(self, design_points: List[str]):
        """
        Clear Generated Data.
        
        Parameters
        ----------
            design_points : typing.List[str]
                'design_points' child.
        
        """

    def update_current(self, ):
        """
        Update Current Design Point.
        """

    def update_all(self, ):
        """
        Update All Design Point.
        """

    def update_selected(self, design_points: List[str]):
        """
        Update Selected Design Points.
        
        Parameters
        ----------
            design_points : typing.List[str]
                'design_points' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class run_calculation:
    fluent_name = ...
    child_names = ...
    adaptive_time_stepping = ...
    cfl_based_adaptive_time_stepping = ...
    data_sampling = ...
    transient_controls = ...
    command_names = ...

    def dual_time_iterate(self, number_of_total_periods: int, number_of_time_steps: int, total_number_of_time_steps: int, total_time: Union[float, str], incremental_time: Union[float, str], max_iteration_per_step: int, postprocess: bool, num_of_post_iter_per_timestep: int):
        """
        Perform unsteady iterations.
        
        Parameters
        ----------
            number_of_total_periods : int
                Set number of total periods.
            number_of_time_steps : int
                Set inceremtal number of Time steps.
            total_number_of_time_steps : int
                Set total number of Time steps.
            total_time : real
                Set Total Simulation Time.
            incremental_time : real
                Set Incremental Time.
            max_iteration_per_step : int
                Set Maximum Number of iterations per time step.
            postprocess : bool
                Enable/Disable Postprocess pollutant solution?.
            num_of_post_iter_per_timestep : int
                Set Number of post-processing iterations per time step.
        
        """

    def iterate(self, number_of_iterations: int):
        """
        Perform a specified number of iterations.
        
        Parameters
        ----------
            number_of_iterations : int
                Set inceremtal number of Time steps.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .method_4 import method as method_cls
from .value_1 import value as value_cls
from .user_defined import user_defined as user_defined_cls
class electrolyte_t_plus(Group):
    """
    'electrolyte_t_plus' child.
    """

    fluent_name = "electrolyte-t-plus"

    child_names = \
        ['method', 'value', 'user_defined']

    method: method_cls = method_cls
    """
    method child of electrolyte_t_plus.
    """
    value: value_cls = value_cls
    """
    value child of electrolyte_t_plus.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of electrolyte_t_plus.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class parametric_project:
    fluent_name = ...
    command_names = ...

    def new(self, project_filename: str):
        """
        Create New Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def open(self, project_filename: str, load_case: bool):
        """
        Open project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
            load_case : bool
                'load_case' child.
        
        """

    def save(self, ):
        """
        Save Project.
        """

    def save_as(self, project_filename: str):
        """
        Save As Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def save_as_copy(self, project_filename: str, convert_to_managed: bool):
        """
        Save As Project.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
            convert_to_managed : bool
                'convert_to_managed' child.
        
        """

    def archive(self, archive_name: str):
        """
        Archive Project.
        
        Parameters
        ----------
            archive_name : str
                'archive_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fixed import fixed as fixed_cls
from .fixes import fixes as fixes_cls
class fixed_values(Group):
    """
    Help not available.
    """

    fluent_name = "fixed-values"

    child_names = \
        ['fixed', 'fixes']

    fixed: fixed_cls = fixed_cls
    """
    fixed child of fixed_values.
    """
    fixes: fixes_cls = fixes_cls
    """
    fixes child of fixed_values.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class contact_angles:
    fluent_name = ...
    command_names = ...

    def delete(self, name_list: List[str]):
        """
        Delete selected objects.
        
        Parameters
        ----------
            name_list : typing.List[str]
                Select objects to be deleted.
        
        """

    def list(self, ):
        """
        List the names of the objects.
        """

    def list_properties(self, object_name: str):
        """
        List active properties of the object.
        
        Parameters
        ----------
            object_name : str
                Select object for which properties are to be listed.
        
        """

    def make_a_copy(self, from_: str, to: str):
        """
        Create a copy of the object.
        
        Parameters
        ----------
            from_ : str
                Select the object to duplicate.
            to : str
                Specify the name of the new object.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .adapt import adapt as adapt_cls
from .check_before_solve import check_before_solve as check_before_solve_cls
from .check_verbosity import check_verbosity as check_verbosity_cls
from .enhanced_orthogonal_quality import enhanced_orthogonal_quality as enhanced_orthogonal_quality_cls
from .matching_tolerance import matching_tolerance as matching_tolerance_cls
from .show_periodic_shadow_zones import show_periodic_shadow_zones as show_periodic_shadow_zones_cls
from .reorder import reorder as reorder_cls
from .repair_improve import repair_improve as repair_improve_cls
from .surface_mesh import surface_mesh as surface_mesh_cls
from .polyhedra import polyhedra as polyhedra_cls
from .adjacency import adjacency as adjacency_cls
from .check import check as check_cls
from .memory_usage import memory_usage as memory_usage_cls
from .mesh_info import mesh_info as mesh_info_cls
from .quality import quality as quality_cls
from .rotate import rotate as rotate_cls
from .scale import scale as scale_cls
from .size_info import size_info as size_info_cls
from .redistribute_boundary_layer import redistribute_boundary_layer as redistribute_boundary_layer_cls
from .swap_mesh_faces import swap_mesh_faces as swap_mesh_faces_cls
from .smooth_mesh import smooth_mesh as smooth_mesh_cls
from .replace import replace as replace_cls
from .translate import translate as translate_cls
class mesh(Group):
    """
    'mesh' child.
    """

    fluent_name = "mesh"

    child_names = \
        ['adapt', 'check_before_solve', 'check_verbosity',
         'enhanced_orthogonal_quality', 'matching_tolerance',
         'show_periodic_shadow_zones', 'reorder', 'repair_improve',
         'surface_mesh', 'polyhedra']

    adapt: adapt_cls = adapt_cls
    """
    adapt child of mesh.
    """
    check_before_solve: check_before_solve_cls = check_before_solve_cls
    """
    check_before_solve child of mesh.
    """
    check_verbosity: check_verbosity_cls = check_verbosity_cls
    """
    check_verbosity child of mesh.
    """
    enhanced_orthogonal_quality: enhanced_orthogonal_quality_cls = enhanced_orthogonal_quality_cls
    """
    enhanced_orthogonal_quality child of mesh.
    """
    matching_tolerance: matching_tolerance_cls = matching_tolerance_cls
    """
    matching_tolerance child of mesh.
    """
    show_periodic_shadow_zones: show_periodic_shadow_zones_cls = show_periodic_shadow_zones_cls
    """
    show_periodic_shadow_zones child of mesh.
    """
    reorder: reorder_cls = reorder_cls
    """
    reorder child of mesh.
    """
    repair_improve: repair_improve_cls = repair_improve_cls
    """
    repair_improve child of mesh.
    """
    surface_mesh: surface_mesh_cls = surface_mesh_cls
    """
    surface_mesh child of mesh.
    """
    polyhedra: polyhedra_cls = polyhedra_cls
    """
    polyhedra child of mesh.
    """
    command_names = \
        ['adjacency', 'check', 'memory_usage', 'mesh_info', 'quality',
         'rotate', 'scale', 'size_info', 'redistribute_boundary_layer',
         'swap_mesh_faces', 'smooth_mesh', 'replace', 'translate']

    adjacency: adjacency_cls = adjacency_cls
    """
    adjacency command of mesh.
    """
    check: check_cls = check_cls
    """
    check command of mesh.
    """
    memory_usage: memory_usage_cls = memory_usage_cls
    """
    memory_usage command of mesh.
    """
    mesh_info: mesh_info_cls = mesh_info_cls
    """
    mesh_info command of mesh.
    """
    quality: quality_cls = quality_cls
    """
    quality command of mesh.
    """
    rotate: rotate_cls = rotate_cls
    """
    rotate command of mesh.
    """
    scale: scale_cls = scale_cls
    """
    scale command of mesh.
    """
    size_info: size_info_cls = size_info_cls
    """
    size_info command of mesh.
    """
    redistribute_boundary_layer: redistribute_boundary_layer_cls = redistribute_boundary_layer_cls
    """
    redistribute_boundary_layer command of mesh.
    """
    swap_mesh_faces: swap_mesh_faces_cls = swap_mesh_faces_cls
    """
    swap_mesh_faces command of mesh.
    """
    smooth_mesh: smooth_mesh_cls = smooth_mesh_cls
    """
    smooth_mesh command of mesh.
    """
    replace: replace_cls = replace_cls
    """
    replace command of mesh.
    """
    translate: translate_cls = translate_cls
    """
    translate command of mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class set:
    fluent_name = ...
    child_names = ...
    cell_function = ...
    load_distribution = ...
    merge = ...
    partition_origin_vector = ...
    pre_test = ...
    smooth = ...
    print_verbosity = ...
    origin = ...
    laplace_smoothing = ...
    nfaces_as_weights = ...
    face_area_as_weights = ...
    layering = ...
    solid_thread_weight = ...
    stretched_mesh_enhancement = ...
    particle_weight = ...
    vof_free_surface_weight = ...
    isat_weight = ...
    fluid_solid_rebalance_after_read_case = ...
    model_weighted_partition = ...
    dpm_load_balancing = ...
    command_names = ...

    def across_zones(self, across_zone_boundaries: bool):
        """
        Enable partitioning by zone or by domain.
        
        Parameters
        ----------
            across_zone_boundaries : bool
                'across_zone_boundaries' child.
        
        """

    def all_off(self, ):
        """
        Disable all optimization.
        """

    def all_on(self, ):
        """
        Enable all optimization.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_name import report_name as report_name_cls
from .output_dir import output_dir as output_dir_cls
class export_simulation_report_as_html(Command):
    """
    Export the provided simulation report as HTML.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
        output_dir : str
            'output_dir' child.
    
    """

    fluent_name = "export-simulation-report-as-html"

    argument_names = \
        ['report_name', 'output_dir']

    report_name: report_name_cls = report_name_cls
    """
    report_name argument of export_simulation_report_as_html.
    """
    output_dir: output_dir_cls = output_dir_cls
    """
    output_dir argument of export_simulation_report_as_html.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class starting_t_re_initialization(String, _HasAllowedValuesMixin):
    """
    Set starting T-field re-initialization method.
    """

    fluent_name = "starting-t-re-initialization"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .value import value as value_cls
class premix_unburnt_density(Group):
    """
    'premix_unburnt_density' child.
    """

    fluent_name = "premix-unburnt-density"

    child_names = \
        ['option', 'value']

    option: option_cls = option_cls
    """
    option child of premix_unburnt_density.
    """
    value: value_cls = value_cls
    """
    value child of premix_unburnt_density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class controls:
    fluent_name = ...
    child_names = ...
    courant_number = ...
    p_v_controls = ...
    relaxation_factor = ...
    under_relaxation = ...
    pseudo_time_method_local_time_step = ...
    pseudo_time_explicit_relaxation_factor = ...
    acoustics_wave_eqn_controls = ...
    contact_solution_controls = ...
    equations = ...
    limits = ...
    advanced = ...
    command_names = ...

    def reset_solution_controls(self, ):
        """
        Reset the solution controls to default.
        """

    def reset_amg_controls(self, ):
        """
        Rest AMG controls to default.
        """

    def reset_multi_stage_parameters(self, ):
        """
        Reset multi-stage parameters.
        """

    def reset_limits(self, ):
        """
        Reset limits to default.
        """

    def reset_pseudo_time_method_generic(self, ):
        """
        Set pseudo time method parameters to default.
        """

    def reset_pseudo_time_method_equations(self, ):
        """
        Set pseudo time method equation specific usage to default.
        """

    def reset_pseudo_time_method_relaxations(self, ):
        """
        Set pseudo time method relaxation factors to default.
        """

    def reset_pseudo_time_method_scale_factors(self, ):
        """
        Set pseudo time method time scale factors to default.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .const_htc import const_htc as const_htc_cls
from .const_nu import const_nu as const_nu_cls
class heat_exchange(Group):
    """
    'heat_exchange' child.
    """

    fluent_name = "heat-exchange"

    child_names = \
        ['option', 'const_htc', 'const_nu']

    option: option_cls = option_cls
    """
    option child of heat_exchange.
    """
    const_htc: const_htc_cls = const_htc_cls
    """
    const_htc child of heat_exchange.
    """
    const_nu: const_nu_cls = const_nu_cls
    """
    const_nu child of heat_exchange.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .filename_2 import filename as filename_cls
class read_from_file(Command):
    """
    Read data from file.
    
    Parameters
    ----------
        filename : str
            Enter file name.
    
    """

    fluent_name = "read-from-file"

    argument_names = \
        ['filename']

    filename: filename_cls = filename_cls
    """
    filename argument of read_from_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class denoiser(Boolean):
    """
    Denoiser is smart AI tech, where noise from rendering to get clear image at earler. It may lead to higher memory usage.
    """

    fluent_name = "denoiser?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .expression_child import expression_child

class expression(NamedObject[expression_child], _CreatableNamedObjectMixin[expression_child]):
    """
    'expression' child.
    """

    fluent_name = "expression"

    child_object_type: expression_child = expression_child
    """
    child_object_type of expression.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .camera import camera as camera_cls
from .display_states import display_states as display_states_cls
from .auto_scale_3 import auto_scale as auto_scale_cls
from .reset_to_default_view import reset_to_default_view as reset_to_default_view_cls
from .delete_view import delete_view as delete_view_cls
from .last_view import last_view as last_view_cls
from .next_view import next_view as next_view_cls
from .list_views import list_views as list_views_cls
from .restore_view import restore_view as restore_view_cls
from .read_views import read_views as read_views_cls
from .save_view import save_view as save_view_cls
from .write_views import write_views as write_views_cls
class views(Group):
    """
    'views' child.
    """

    fluent_name = "views"

    child_names = \
        ['camera', 'display_states']

    camera: camera_cls = camera_cls
    """
    camera child of views.
    """
    display_states: display_states_cls = display_states_cls
    """
    display_states child of views.
    """
    command_names = \
        ['auto_scale', 'reset_to_default_view', 'delete_view', 'last_view',
         'next_view', 'list_views', 'restore_view', 'read_views', 'save_view',
         'write_views']

    auto_scale: auto_scale_cls = auto_scale_cls
    """
    auto_scale command of views.
    """
    reset_to_default_view: reset_to_default_view_cls = reset_to_default_view_cls
    """
    reset_to_default_view command of views.
    """
    delete_view: delete_view_cls = delete_view_cls
    """
    delete_view command of views.
    """
    last_view: last_view_cls = last_view_cls
    """
    last_view command of views.
    """
    next_view: next_view_cls = next_view_cls
    """
    next_view command of views.
    """
    list_views: list_views_cls = list_views_cls
    """
    list_views command of views.
    """
    restore_view: restore_view_cls = restore_view_cls
    """
    restore_view command of views.
    """
    read_views: read_views_cls = read_views_cls
    """
    read_views command of views.
    """
    save_view: save_view_cls = save_view_cls
    """
    save_view command of views.
    """
    write_views: write_views_cls = write_views_cls
    """
    write_views command of views.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .moments import moments as moments_cls
from .number_density import number_density as number_density_cls
class population_balance(Group):
    """
    'population_balance' child.
    """

    fluent_name = "population-balance"

    command_names = \
        ['moments', 'number_density']

    moments: moments_cls = moments_cls
    """
    moments command of population_balance.
    """
    number_density: number_density_cls = number_density_cls
    """
    number_density command of population_balance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .planar_conductivity import planar_conductivity as planar_conductivity_cls
from .transverse_conductivity import transverse_conductivity as transverse_conductivity_cls
class biaxial(Group):
    """
    'biaxial' child.
    """

    fluent_name = "biaxial"

    child_names = \
        ['planar_conductivity', 'transverse_conductivity']

    planar_conductivity: planar_conductivity_cls = planar_conductivity_cls
    """
    planar_conductivity child of biaxial.
    """
    transverse_conductivity: transverse_conductivity_cls = transverse_conductivity_cls
    """
    transverse_conductivity child of biaxial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class unsteady_tracking:
    fluent_name = ...
    child_names = ...
    option = ...
    create_particles_every_dpm_step = ...
    dpm_time_step_size = ...
    number_of_time_steps = ...
    command_names = ...

    def clear_all_particles(self, ):
        """
        Clear all particles currently in the domain.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class port_span(Integer):
    """
    Number of ports to try starting from given 'port' for the web server.
    """

    fluent_name = "port-span"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class partition:
    fluent_name = ...
    child_names = ...
    auto = ...
    set = ...
    command_names = ...

    def combine_partition(self, number_of_partitions: int):
        """
        Merge every N partitions.
        
        Parameters
        ----------
            number_of_partitions : int
                'number_of_partitions' child.
        
        """

    def merge_clusters(self, merge_iterations: int):
        """
        Merge partition clusters.
        
        Parameters
        ----------
            merge_iterations : int
                'merge_iterations' child.
        
        """

    def method(self, partition_method: str, count: int):
        """
        Partition the domain.
        
        Parameters
        ----------
            partition_method : str
                'partition_method' child.
            count : int
                'count' child.
        
        """

    def print_partitions(self, ):
        """
        Print partition information.
        """

    def print_active_partitions(self, ):
        """
        Print active partition information.
        """

    def print_stored_partitions(self, ):
        """
        Print stored partition information.
        """

    def reorder_partitions(self, ):
        """
        Reorder partitions.
        """

    def reorder_partitions_to_architecture(self, ):
        """
        Reorder partitions to architecture.
        """

    def smooth_partition(self, smoothing_iteration: int):
        """
        Smooth partition interface.
        
        Parameters
        ----------
            smoothing_iteration : int
                Set maximum number of smoothing iterations.
        
        """

    def use_stored_partitions(self, ):
        """
        Use stored partitioning.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class report_plots_child:
    fluent_name = ...
    child_names = ...
    name = ...
    plot_window = ...
    frequency = ...
    flow_frequency = ...
    frequency_of = ...
    report_defs = ...
    print = ...
    title = ...
    x_label = ...
    y_label = ...
    active = ...
    plot_instantaneous_values = ...
    axes = ...
    curves = ...
    command_names = ...

    def plot(self, ):
        """
        Display the report-plot.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .update_sources_every_flow_iteration import update_sources_every_flow_iteration as update_sources_every_flow_iteration_cls
from .iteration_interval import iteration_interval as iteration_interval_cls
class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['option', 'update_sources_every_flow_iteration',
         'iteration_interval']

    option: option_cls = option_cls
    """
    option child of interaction.
    """
    update_sources_every_flow_iteration: update_sources_every_flow_iteration_cls = update_sources_every_flow_iteration_cls
    """
    update_sources_every_flow_iteration child of interaction.
    """
    iteration_interval: iteration_interval_cls = iteration_interval_cls
    """
    iteration_interval child of interaction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .auto_range import auto_range as auto_range_cls
from .clip_to_range_1 import clip_to_range as clip_to_range_cls
class range(Group):
    """
    'range' child.
    """

    fluent_name = "range"

    child_names = \
        ['option', 'auto_range', 'clip_to_range']

    option: option_cls = option_cls
    """
    option child of range.
    """
    auto_range: auto_range_cls = auto_range_cls
    """
    auto_range child of range.
    """
    clip_to_range: clip_to_range_cls = clip_to_range_cls
    """
    clip_to_range child of range.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .child_object_type_child_1 import child_object_type_child

class ablation_species_mf(NamedObject[child_object_type_child], _NonCreatableNamedObjectMixin[child_object_type_child]):
    """
    'ablation_species_mf' child.
    """

    fluent_name = "ablation-species-mf"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of ablation_species_mf.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .volume_heat_run import volume_heat_run as volume_heat_run_cls
from .face_heat_run import face_heat_run as face_heat_run_cls
from .face_temperature_run import face_temperature_run as face_temperature_run_cls
from .joule_heat_run import joule_heat_run as joule_heat_run_cls
class file_saving_frequency(Group):
    """
    'file_saving_frequency' child.
    """

    fluent_name = "file-saving-frequency"

    child_names = \
        ['volume_heat_run', 'face_heat_run', 'face_temperature_run',
         'joule_heat_run']

    volume_heat_run: volume_heat_run_cls = volume_heat_run_cls
    """
    volume_heat_run child of file_saving_frequency.
    """
    face_heat_run: face_heat_run_cls = face_heat_run_cls
    """
    face_heat_run child of file_saving_frequency.
    """
    face_temperature_run: face_temperature_run_cls = face_temperature_run_cls
    """
    face_temperature_run child of file_saving_frequency.
    """
    joule_heat_run: joule_heat_run_cls = joule_heat_run_cls
    """
    joule_heat_run child of file_saving_frequency.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cell_zones_6 import cell_zones as cell_zones_cls
from .cell_function_1 import cell_function as cell_function_cls
from .current_domain import current_domain as current_domain_cls
from .write_to_file_1 import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
class volume(Command):
    """
    Print total volume of specified cell zones.
    
    Parameters
    ----------
        cell_zones : typing.List[str]
            Volume id/name.
        cell_function : str
            Specify Field.
        current_domain : str
            'current_domain' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
    
    """

    fluent_name = "volume"

    argument_names = \
        ['cell_zones', 'cell_function', 'current_domain', 'write_to_file',
         'file_name', 'append_data']

    cell_zones: cell_zones_cls = cell_zones_cls
    """
    cell_zones argument of volume.
    """
    cell_function: cell_function_cls = cell_function_cls
    """
    cell_function argument of volume.
    """
    current_domain: current_domain_cls = current_domain_cls
    """
    current_domain argument of volume.
    """
    write_to_file: write_to_file_cls = write_to_file_cls
    """
    write_to_file argument of volume.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of volume.
    """
    append_data: append_data_cls = append_data_cls
    """
    append_data argument of volume.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .motion import motion as motion_cls
from .parent_1 import parent_1 as parent_1_cls
from .initial_state import initial_state as initial_state_cls
from .display_state import display_state as display_state_cls
class reference_frames_child(Group):
    """
    'child_object_type' of reference_frames.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['motion', 'parent_1', 'initial_state', 'display_state']

    motion: motion_cls = motion_cls
    """
    motion child of reference_frames_child.
    """
    parent_1: parent_1_cls = parent_1_cls
    """
    parent_1 child of reference_frames_child.
    """
    initial_state: initial_state_cls = initial_state_cls
    """
    initial_state child of reference_frames_child.
    """
    display_state: display_state_cls = display_state_cls
    """
    display_state child of reference_frames_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class participates_in_solar_ray_tracing(Boolean, _HasAllowedValuesMixin):
    """
    Participates in Solar Ray Tracing.
    """

    fluent_name = "participates-in-solar-ray-tracing"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .set_cgns_export_filetype import set_cgns_export_filetype as set_cgns_export_filetype_cls
class settings(Group):
    """
    Enter the export settings menu.
    """

    fluent_name = "settings"

    command_names = \
        ['set_cgns_export_filetype']

    set_cgns_export_filetype: set_cgns_export_filetype_cls = set_cgns_export_filetype_cls
    """
    set_cgns_export_filetype command of settings.
    """



"""Module providing additional execution methods."""
from concurrent.futures import ThreadPoolExecutor
import functools
from multiprocessing.context import TimeoutError
import multiprocessing.pool
import time
from typing import Any, Callable, Optional

from ansys.fluent.core.exceptions import InvalidArgument


def asynchronous(f: Callable) -> Callable:
    """Use for decorating functions that are to execute asynchronously. The decorated
    function returns a `future`_ object. Calling `result()`_ on the future object
    synchronizes the function execution.

    Examples
    --------
    asynchronous execution using @asynchronous decorator

    >>> @asynchronous
    ... def asynchronous_solve(solver_session, number_of_iterations):
    ...     solver_session.tui.solve.iterate(number_of_iterations)
    >>> asynchronous_solve(solver_session_1, 100)

    using the asynchronous function directly

    >>> asynchronous(solver_session_2.tui.solve.iterate)(100)

    synchronous execution of above 2 calls

    >>> asynchronous_solve(solver_session_1, 100).result()
    >>> asynchronous(solver_session_2.tui.solve.iterate)(100).result()

    .. _Future: https://docs.python.org/3/library/asyncio-future.html#future-object  # noqa: E501
    .. _result(): https://docs.python.org/3/library/asyncio-future.html#asyncio.Future.result  # noqa: E501
    """

    @functools.wraps(f)
    def func(*args, **kwargs) -> Callable:
        return ThreadPoolExecutor(max_workers=1).submit(f, *args, **kwargs)

    return func


def timeout_exec(obj, timeout, args=None, kwargs=None):
    """Executes object with the timeout limit. Tries to return whatever the provided
    object returns. If the object returns nothing, this function will return ``True``.
    If it times out, returns ``False``.

    Parameters
    ----------
    obj : Any
        Object to execute.
    timeout : float
        Time before cancelling execution and returning early.
    args : Any, optional
        Arguments to be passed to the specified object.
    kwargs : Any, optional
        Keyword arguments to be passed to the specified object.

    Examples
    --------
    Execute ``time.sleep()`` for 2 seconds, with a timeout of 1 second:

    >>> import time
    >>> from ansys.fluent.core.utils.execution import timeout_exec
    >>> ret = timeout_exec(time.sleep,timeout=1,args=(2,))
    >>> assert ret is False
    """
    if args is None:
        args = ()
    if kwargs is None:
        kwargs = {}

    def _exec(*_args, **_kwargs):
        if callable(obj):
            return obj(*_args, **_kwargs)
        else:
            return obj

    pool = multiprocessing.pool.ThreadPool(processes=1)
    async_result = pool.apply_async(_exec, args=args, kwds=kwargs)
    try:
        return_obj = async_result.get(timeout=timeout)
        pool.close()
        if not return_obj and return_obj is not False:
            return True
        return return_obj
    except TimeoutError:
        pool.terminate()
        return False


def timeout_loop(
    obj: Any,
    timeout: float,
    args: Optional[Any] = None,
    kwargs: Optional[Any] = None,
    idle_period: float = 0.2,
    expected: str = "truthy",
) -> Any:
    """Loops while specified object does not return expected response. Timeouts after
    specified time has elapsed. Tries to return whatever is returned by the specified
    object. If nothing is returned before timeout, returns the opposite of the expected
    value, i.e. ``True`` if ``expected == "falsy"`` and ``False`` if ``expected ==
    "truthy"``.

    Parameters
    ----------
    obj : Any
        Object to evaluate while looping if it does not return expected response.
    timeout : float
        Time before cancelling execution and returning early.
    args : Any, optional
        Arguments to be passed to the specified object.
    kwargs : Any, optional
        Keyword arguments to be passed to the specified object.
    idle_period : float, optional
        Time in seconds to wait between object evaluations, defaults to 0.2 seconds.
    expected: str, optional
        Possible values are ``"truthy"`` or ``"falsy"``, indicating what type of return is expected.
        By default, expects a ``"truthy"`` return from the specified object.

    Raises
    ------
    InvalidArgument
        If an unrecognized value is passed for ``expected``.

    Examples
    --------
    Waiting 5 seconds to see if ``func("test")`` returns True:

    >>> func("test")
    False
    >>> response = timeout_loop(func, timeout=5.0, args=("test",))

    Waiting 5 seconds to see if ``func2("test",word="hello")`` returns False:

    >>> func2("test", word="hello")
    True
    >>> response = timeout_loop(func2, timeout=5.0, expected="falsy", args=("test",), kwargs={"word":"hello",})
    """
    if args is None:
        args = ()
    if kwargs is None:
        kwargs = {}

    def _exec(*_args, **_kwargs):
        if callable(obj):
            return obj(*_args, **_kwargs)
        else:
            return obj

    time_elapsed = 0.0
    while time_elapsed <= timeout:
        ret_obj = _exec(*args, **kwargs)
        if expected == "truthy":
            if ret_obj:
                return ret_obj
        elif expected == "falsy":
            if not ret_obj:
                return ret_obj
        else:
            raise InvalidArgument("Specify 'expected' as either 'truthy' or 'falsy'.")
        time.sleep(idle_period)
        time_elapsed += idle_period

    if expected == "truthy":
        return False
    elif expected == "falsy":
        return True



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class by_surface:
    fluent_name = ...
    child_names = ...
    use_inherent_material_color = ...
    command_names = ...

    def reset(self, ):
        """
        To reset colors and/or materials to the defaults.
        """

    def list_surfaces_by_color(self, ):
        """
        To list the surfaces by its color.
        """

    def list_surfaces_by_material(self, ):
        """
        To list the surfaces by its material.
        """

    def surfaces(self, surface_names: List[str], color: str, material: str):
        """
        Select the surface(s) to specify colors and/or materials.
        
        Parameters
        ----------
            surface_names : typing.List[str]
                Enter the list of surfaces to set color and material.
            color : str
                'color' child.
            material : str
                'material' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class surface_reaction_rate_temperature_factor(Real):
    """
    Set the surface reaction parameters for the Non-Equilibrium Thermal Model: Surface reaction-rate temperature factor.
    """

    fluent_name = "surface-reaction-rate-temperature-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cell_thread_list import cell_thread_list as cell_thread_list_cls
from .max_cell_skewness import max_cell_skewness as max_cell_skewness_cls
from .convert_skewed_cells import convert_skewed_cells as convert_skewed_cells_cls
class convert_skewed_cells(Command):
    """
    'convert_skewed_cells' command.
    
    Parameters
    ----------
        cell_thread_list : typing.List[str]
            Set zones where cells should be converted.
        max_cell_skewness : real
            Set target maximum cell skewness.
        convert_skewed_cells : bool
            'convert_skewed_cells' child.
    
    """

    fluent_name = "convert-skewed-cells"

    argument_names = \
        ['cell_thread_list', 'max_cell_skewness', 'convert_skewed_cells']

    cell_thread_list: cell_thread_list_cls = cell_thread_list_cls
    """
    cell_thread_list argument of convert_skewed_cells.
    """
    max_cell_skewness: max_cell_skewness_cls = max_cell_skewness_cls
    """
    max_cell_skewness argument of convert_skewed_cells.
    """
    convert_skewed_cells: convert_skewed_cells_cls = convert_skewed_cells_cls
    """
    convert_skewed_cells argument of convert_skewed_cells.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .setting_type import setting_type as setting_type_cls
class modified_setting(Command):
    """
    Specify which settings will be checked for non-default status for generating the Modified Settings Summary table.
    
    Parameters
    ----------
        setting_type : typing.List[str]
            'setting_type' child.
    
    """

    fluent_name = "modified-setting"

    argument_names = \
        ['setting_type']

    setting_type: setting_type_cls = setting_type_cls
    """
    setting_type argument of modified_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class timer:
    fluent_name = ...
    command_names = ...

    def usage(self, ):
        """
        Print solver timer.
        """

    def reset(self, ):
        """
        Reset domain timers.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class heat_exchanger:
    fluent_name = ...
    command_names = ...

    def computed_heat_rejection(self, heat_exchanger: str, fluid_zone: str, boundary_zone: str, report_type: str, write_to_file: bool, file_name: str, append_file: bool):
        """
        Print total heat rejection.
        
        Parameters
        ----------
            heat_exchanger : str
                'heat_exchanger' child.
            fluid_zone : str
                'fluid_zone' child.
            boundary_zone : str
                Enter face zone name.
            report_type : str
                'report_type' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_file : bool
                'append_file' child.
        
        """

    def inlet_temperature(self, heat_exchanger: str, fluid_zone: str, boundary_zone: str, report_type: str, write_to_file: bool, file_name: str, append_file: bool):
        """
        Print inlet temperature.
        
        Parameters
        ----------
            heat_exchanger : str
                'heat_exchanger' child.
            fluid_zone : str
                'fluid_zone' child.
            boundary_zone : str
                Enter face zone name.
            report_type : str
                'report_type' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_file : bool
                'append_file' child.
        
        """

    def outlet_temperature(self, heat_exchanger: str, fluid_zone: str, boundary_zone: str, report_type: str, write_to_file: bool, file_name: str, append_file: bool):
        """
        Print outlet temperature.
        
        Parameters
        ----------
            heat_exchanger : str
                'heat_exchanger' child.
            fluid_zone : str
                'fluid_zone' child.
            boundary_zone : str
                Enter face zone name.
            report_type : str
                'report_type' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_file : bool
                'append_file' child.
        
        """

    def mass_flow_rate(self, heat_exchanger: str, fluid_zone: str, boundary_zone: str, report_type: str, write_to_file: bool, file_name: str, append_file: bool):
        """
        Print mass flow rate.
        
        Parameters
        ----------
            heat_exchanger : str
                'heat_exchanger' child.
            fluid_zone : str
                'fluid_zone' child.
            boundary_zone : str
                Enter face zone name.
            report_type : str
                'report_type' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_file : bool
                'append_file' child.
        
        """

    def specific_heat(self, heat_exchanger: str, fluid_zone: str, boundary_zone: str, report_type: str, write_to_file: bool, file_name: str, append_file: bool):
        """
        Print fluid's specific heat.
        
        Parameters
        ----------
            heat_exchanger : str
                'heat_exchanger' child.
            fluid_zone : str
                'fluid_zone' child.
            boundary_zone : str
                Enter face zone name.
            report_type : str
                'report_type' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_file : bool
                'append_file' child.
        
        """

